<?php
/**
 * Admin End Hooks
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Admin;

defined( 'ABSPATH' ) || exit(); // Exit if access directly.

use WkMarketplace\Helper\Admin;

if ( ! class_exists( 'WKMP_Admin_Ajax_Functions_Pro' ) ) {
	/**
	 * Admin Functions class
	 */
	class WKMP_Admin_Ajax_Functions_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Marketplace class obj.
		 *
		 * @var $wkmarketplace
		 */
		private $wkmarketplace;

		/**
		 * Constructor.
		 */
		public function __construct() {
			global $wkmarketplace;
			$this->wkmarketplace = $wkmarketplace;
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Approve/Disapprove Seller.
		 *
		 * @return void
		 */
		public function wkmp_pro_approve_disapprove_seller() {
			$json = array(
				'error'   => false,
				'message' => '',
				'action'  => 'approve',
				'success' => false,
			);

			if ( ! check_ajax_referer( 'wkmp-admin-nonce', 'wkmp_nonce', false ) ) {
				$json['error']   = true;
				$json['message'] = esc_html__( 'Security check failed!', 'wk-marketplace' );
				wp_send_json( $json );
				die();
			}

			$posted_data = isset( $_POST ) ? wc_clean( $_POST ) : array(); //phpcs:ignore WordPress.Security.NonceVerification.Missing

			if ( ! empty( $posted_data['seller_id'] ) ) {
				global $wpdb;

				$seller_id      = $posted_data['seller_id'];
				$wp_user_object = get_user_by( 'ID', $seller_id );
				$seller_db_obj  = Admin\WKMP_Seller_Data::get_instance();
				$role           = 'customer';

				if ( $this->wkmarketplace->wkmp_user_is_seller( $seller_id ) ) {
					$json['message'] = esc_html__( 'Approve', 'wk-marketplace' );
					$seller_db_obj->wkmp_disapprove_seller( $seller_id, $wp_user_object );
				} else {
					$role            = 'seller';
					$json['message'] = esc_html__( 'Disapprove', 'wk-marketplace' );
					$json['action']  = 'disapprove';

					$wp_user_object->set_role( 'wk_marketplace_seller' );

					$wpdb->get_results( $wpdb->prepare( "UPDATE {$wpdb->prefix}posts SET post_status = 'publish' WHERE post_author = %d", $seller_id ) );

					do_action( 'wkmp_seller_account_approved', $seller_id );
				}
				$seller_db_obj->wkmp_update_seller_role( $seller_id, $role );
				$json['success'] = true;
			}
			wp_send_json( $json );
			die();
		}

		/**
		 * Validating seller shipping zone on separate seller dashboard.
		 */
		public function wkmp_pro_separate_seller_shipping_zone() {
			global $wpdb;
			if ( check_ajax_referer( 'wkmp-admin-nonce', 'wkmp_nonce', false ) ) {
				$result  = array( 'success' => false );
				$zone_id = empty( $_POST['zone_id'] ) ? 0 : intval( wc_clean( $_POST['zone_id'] ) );

				if ( $zone_id > 0 ) {
					$seller_id    = get_current_user_id();
					$seller_zones = $wpdb->get_results( $wpdb->prepare( "SELECT zone_id FROM {$wpdb->prefix}mpseller_meta WHERE seller_id = %d", $seller_id ), ARRAY_A );

					$zone_ids = wp_list_pluck( $seller_zones, 'zone_id' );
					$zone_ids = array_map( 'intval', $zone_ids );

					$result['zone_id']  = $zone_id;
					$result['zone_ids'] = $zone_ids;

					if ( in_array( $zone_id, $zone_ids, true ) ) {
						$result['success'] = true;

					}
				}
				wp_send_json( $result );
			}
		}
	}
}
