<?php
/**
 * Admin End Functions
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Admin;

defined( 'ABSPATH' ) || exit(); // Exit if access directly.

use WkMarketplace\Helper;
use WkMarketplace\Helper\Common as HelperCommon; // Lite common helper class.

if ( ! class_exists( 'WKMP_Admin_Functions_Pro' ) ) {
	/**
	 * Admin hooks class
	 */
	class WKMP_Admin_Functions_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Constructor of the class.
		 */
		public function __construct() {
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Register Options
		 *
		 * @return void
		 */
		public function wkmp_pro_register_marketplace_options() {
			register_setting( 'wkmp-general-settings-group', '_wkmp_auto_approve_seller' );
			register_setting( 'wkmp-general-settings-group', '_wkmp_separate_seller_dashboard' );
			register_setting( 'wkmp-general-settings-group', '_wkmp_separate_seller_registration' );
			register_setting( 'wkmp-general-settings-group', 'wkmp_shipping_option' );
			register_setting( 'wkmp-general-settings-group', 'wkmp_seller_terms_page_id' );
			register_setting( 'wkmp-product-settings-group', '_wkmp_allow_seller_to_publish' );

			register_setting( 'wkmp-google-analytics-settings-group', '_wkmp_enable_google_analytics' );
			register_setting( 'wkmp-google-analytics-settings-group', '_wkmp_google_account_number' );
			register_setting( 'wkmp-google-analytics-settings-group', '_wkmp_analytics_anonymize_ip' );

			register_setting( 'wkmp-endpoint-settings-group', '_wkmp_dashboard_endpoint' );

			$endpoint_settings = apply_filters(
				'wkmp_endpoint_settings',
				array(
					'_wkmp_dashboard_endpoint',
					'_wkmp_product_list_endpoint',
					'_wkmp_add_product_endpoint',
					'_wkmp_edit_product_endpoint',
					'_wkmp_order_history_endpoint',
					'_wkmp_transaction_endpoint',
					'_wkmp_notification_endpoint',
					'_wkmp_shipping_endpoint',
					'_wkmp_become_seller_endpoint',
					'_wkmp_admin_dashboard_endpoint',
					'_wkmp_profile_endpoint',
					'_wkmp_shop_follower_endpoint',
					'_wkmp_asktoadmin_endpoint',
					'_wkmp_seller_product_endpoint',
					'_wkmp_store_endpoint',
					'_wkmp_feedbacks_endpoint',
					'_wkmp_add_feedback_endpoint',
					'_wkmp_favorite_seller_endpoint',
				)
			);

			$endpoint_name_settings = apply_filters(
				'wkmp_endpoint_name_settings',
				array(
					'_wkmp_dashboard_endpoint_name',
					'_wkmp_product_list_endpoint_name',
					'_wkmp_add_product_endpoint_name',
					'_wkmp_edit_product_endpoint_name',
					'_wkmp_order_history_endpoint_name',
					'_wkmp_transaction_endpoint_name',
					'_wkmp_profile_endpoint_name',
					'_wkmp_shipping_endpoint_name',
					'_wkmp_become_seller_endpoint_name',
					'_wkmp_admin_dashboard_endpoint_name',
					'_wkmp_notification_endpoint_name',
					'_wkmp_shop_follower_endpoint_name',
					'_wkmp_asktoadmin_endpoint_name',
					'_wkmp_seller_product_endpoint_name',
					'_wkmp_store_endpoint_name',
					'_wkmp_feedbacks_endpoint_name',
					'_wkmp_add_feedback_endpoint_name',
					'_wkmp_favorite_seller_endpoint_name',
				)
			);

			foreach ( $endpoint_settings as $value ) {
				register_setting( 'wkmp-endpoint-settings-group', $value, array( $this, 'wkmp_pro_save_wc_endpoints' ) );
			}

			foreach ( $endpoint_name_settings as $value ) {
				register_setting( 'wkmp-endpoint-settings-group', $value );
			}
		}

		/**
		 * Admin end scripts
		 *
		 * @return void
		 */
		public function wkmp_pro_admin_scripts() {
			$suffix = ( defined( 'WKWC_DEV' ) && true === WKWC_DEV ) ? '' : '.min';
			$path   = ( defined( 'WKWC_DEV' ) && true === WKWC_DEV ) ? 'build' : 'dist';

			wp_enqueue_style( 'wkmp-pro-admin-style', WKMP_PLUGIN_URL . 'assets/' . $path . '/admin/css/admin' . $suffix . '.css', array(), WKMP_SCRIPT_VERSION );
			wp_enqueue_script( 'wkmp-pro-admin-script', WKMP_PLUGIN_URL . 'assets/' . $path . '/admin/js/admin' . $suffix . '.js', array(), WKMP_SCRIPT_VERSION, true );

			if ( get_option( '_wkmp_separate_seller_dashboard', false ) && get_user_meta( get_current_user_id(), 'wkmp_seller_backend_dashboard', true ) ) {
				$oid         = \WK_Caching::wk_get_request_data( 'oid', array( 'filter' => 'int' ) );
				$page_name   = \WK_Caching::wk_get_request_data( 'page' );
				$action_name = \WK_Caching::wk_get_request_data( 'action' );

				if ( is_admin() && $this->wkmp_pro_is_backend_seller_page( $page_name ) ) {
					wp_enqueue_style( 'wkmp-front-style-css', WKMP_LITE_PLUGIN_URL . 'assets/' . $path . '/front/css/front' . $suffix . '.css', array(), WKMP_LITE_SCRIPT_VERSION );
					wp_enqueue_style( 'wkmp-front-style', WKMP_LITE_PLUGIN_URL . 'assets/' . $path . '/front/css/style' . $suffix . '.css', array(), WKMP_LITE_SCRIPT_VERSION );
					wp_enqueue_style( 'wkmp-backend-style', WKMP_PLUGIN_URL . 'assets/' . $path . '/front/css/backend-style' . $suffix . '.css', array(), WKMP_SCRIPT_VERSION );
					wp_register_script( 'jquery', '//code.jquery.com/jquery-2.2.4.min.js', array(), WKMP_LITE_SCRIPT_VERSION, true );
					wp_enqueue_script( 'jquery' );
					wp_enqueue_script( 'google_chart', 'https://www.gstatic.com/charts/loader.js', array(), WKMP_LITE_SCRIPT_VERSION, false );
					wp_enqueue_script( 'mp_chart_script', '//cdnjs.cloudflare.com/ajax/libs/Chart.js/2.7.1/Chart.min.js', array(), WKMP_LITE_SCRIPT_VERSION, false );
				}

				if ( ( 'order-history' === $page_name && 'view' === $action_name && $oid > 0 ) || 'seller-profile' === $page_name ) {
					wp_enqueue_script( 'wkmp-front-script', WKMP_LITE_PLUGIN_URL . 'assets/' . $path . '/front/js/front' . $suffix . '.js', array( 'select2', 'wp-util' ), WKMP_LITE_SCRIPT_VERSION, true );
				}
			}
		}

		/**
		 * To check if the page seller back end page.
		 *
		 * @param string $page_slug Page slug.
		 *
		 * @return bool
		 */
		public function wkmp_pro_is_backend_seller_page( $page_slug ) {
			return in_array(
				$page_slug,
				apply_filters(
					'wkmp_pro_seller_backend_pages_slugs', // To allow addons to register their admin page slugs.
					array(
						'seller',
						'order-history',
						'seller-transaction',
						'seller-notifications',
						'seller-shop-followers',
						'seller-profile',
						'ask-to-admin',
					)
				),
				true
			);
		}

		/**
		 * Restricting to save endpoint that are already registered in WooCommerce.
		 *
		 * @param string $endpoint_slug Endpoint slug.
		 *
		 * @return string
		 */
		public function wkmp_pro_save_wc_endpoints( $endpoint_slug ) {
			global $wkmarketplace;
			$wc_endpoints = $wkmarketplace->wkmp_get_wc_registered_endpoints();

			if ( ! in_array( $endpoint_slug, $wc_endpoints, true ) ) {
				return $endpoint_slug;
			} else {
				add_settings_error( '_wkmp_dashboard_endpoint', 'dashboard-error', ( wp_sprintf( /* translators: %s: Endpoint slug. */ esc_html__( 'Endpoint "%s" is already registered in Woocommerce.', 'wk-marketplace' ), esc_attr( $endpoint_slug ) ) ), 'error' );

				return '';
			}
		}

		/**
		 * Allow seller commission settings.
		 *
		 * @param array $fields Form fields.
		 *
		 * @return array
		 */
		public function wkmp_pro_update_seller_commission_settings( $fields ) {
			if ( ! empty( $fields['entry']['fields']['wkmp_seller_commission']['show_lock'] ) ) {
				$fields['entry']['fields']['wkmp_seller_commission']['show_lock'] = false;
			}
			if ( ! empty( $fields['entry']['fields']['wkmp_seller_commission']['readonly'] ) ) {
				$fields['entry']['fields']['wkmp_seller_commission']['readonly'] = false;
			}
			return $fields;
		}

		/**
		 * Allow seller order approval settings.
		 *
		 * @param array $fields Form fields.
		 *
		 * @return array
		 */
		public function wkmp_pro_update_seller_misc_settings( $fields ) {
			if ( ! empty( $fields['entry']['fields']['_wkmp_enable_seller_order_approval']['show_lock'] ) ) {
				$fields['entry']['fields']['_wkmp_enable_seller_order_approval']['show_lock'] = false;
			}
			return $fields;
		}

		/**
		 * Allow seller to publish pruduct settings.
		 *
		 * @param array $fields Form fields.
		 *
		 * @return array
		 */
		public function wkmp_pro_admin_product_update_settings( $fields ) {
			if ( ! empty( $fields['entry']['fields']['_wkmp_allow_seller_to_publish']['show_lock'] ) ) {
				$fields['entry']['fields']['_wkmp_allow_seller_to_publish']['show_lock'] = false;
			}
			return $fields;
		}

		/**
		 * Enable save commission button on save seller commission.
		 *
		 * @param array $attributes Attributes.
		 *
		 * @return array
		 */
		public function wkmp_pro_seller_save_button_attributes_enable( $attributes = array() ) {
			if ( isset( $attributes['disabled'] ) ) {
				unset( $attributes['disabled'] );
			}

			return $attributes;
		}

		/**
		 * Call back method for Save seller commission
		 *
		 * @param int $commission_info commission info.
		 * @param int $seller_id seller id.
		 */
		public function wkmp_pro_update_seller_commission( $commission_info, $seller_id ) {
			if ( $seller_id ) {
				$commission_obj = HelperCommon\WKMP_Commission::get_instance();
				$commission_obj->wkmp_update_seller_commission_info( $seller_id, array( 'commision_on_seller' => $commission_info['wkmp_seller_commission'] ) );
			}
		}

		/**
		 * Updated order approval settings.
		 *
		 * @param array $posted_data Form posted data.
		 * @param int   $seller_id seller id.
		 */
		public function wkmp_pro_seller_misc_settings_update( $posted_data, $seller_id ) {
			$nonce = \WK_Caching::wk_get_request_data( 'wkmp-admin-seller-misc-nonce-value', array( 'method' => 'post' ) );

			if ( ! empty( $nonce ) && wp_verify_nonce( $nonce, 'wkmp-admin-seller-misc-nonce-action' ) ) {

				$enable_order_approval = empty( $_POST['_wkmp_enable_seller_order_approval'] ) ? false : wc_clean( wp_unslash( $_POST['_wkmp_enable_seller_order_approval'] ) );

				update_user_meta( $seller_id, '_wkmp_enable_seller_order_approval', $enable_order_approval );
			}
		}

		/**
		 * Change assigned seller to products.
		 */
		public function wkmp_pro_assign_products_to_seller() {
			$prod_seller = \WK_Caching::wk_get_request_data( 'mp-assign-product-seller' );

			if ( 'Assign' === $prod_seller ) {
				$assign_product = \WK_Caching::wk_get_request_data( 'wkmp_change_seller' );
				$ids            = \WK_Caching::wk_get_request_data( 'ids', array( 'flag' => 'array' ) );

				if ( ! empty( $assign_product ) && ! empty( $ids ) ) {
					$this->wkmp_assign_product_to_seller( $assign_product, $ids );
				}
			}
		}

		/**
		 * Assign product to seller.
		 *
		 * @param int   $seller_id Seller id.
		 * @param array $product_ids Product ids.
		 */
		public function wkmp_assign_product_to_seller( $seller_id, $product_ids ) {
			foreach ( $product_ids as $product_id ) {
				$arg = array(
					'ID'          => intval( $product_id ),
					'post_author' => $seller_id,
				);
				wp_update_post( $arg );

				$args       = array(
					'numberposts' => - 1,
					'order'       => 'ASC',
					'post_parent' => intval( $product_id ),
					'post_type'   => 'product_variation',
				);
				$variations = get_children( $args );

				if ( $variations ) {
					foreach ( $variations as $val ) {
						$arg = array(
							'ID'          => $val->ID,
							'post_author' => $seller_id,
						);
						wp_update_post( $arg );
					}
				}
			}

			$page_name = \WK_Caching::wk_get_request_data( 'page' );
			$url       = 'admin.php?page=' . $page_name . '&success=2';

			wp_safe_redirect( admin_url( $url ) );
			exit( 0 );
		}

		/**
		 * Add filter seller arguments.
		 *
		 * @param array $args Filter product data.
		 */
		public function wkmp_pro_add_seller_filter_data( $args ) {
			$assign_seller_button = \WK_Caching::wk_get_request_data( 'wkmp_filter_assign_seller_button' );

			$filter_assign_seller_id = 0;
			$wkmp_assigned_option    = false;

			if ( 'Filter' === $assign_seller_button ) {
				$wkmp_assigned_option    = \WK_Caching::wk_get_request_data( 'wkmp_filter_assign_seller_option' );
				$filter_assign_seller_id = \WK_Caching::wk_get_request_data( 'wkmp_filter_by_seller', array( 'filter' => 'int' ) );
			}

			$args['filter_seller_id'] = $filter_assign_seller_id;
			$args['filter_assigned']  = $wkmp_assigned_option;
			$args['search']           = \WK_Caching::wk_get_request_data( 's' );

			return $args;
		}

		/**
		 * Add filter seller arguments.
		 *
		 * @param array $args Filter product data.
		 */
		public function wkmp_pro_add_search_filter_data( $args ) {
			$args['search'] = \WK_Caching::wk_get_request_data( 's' );

			return $args;
		}

		/**
		 * Add Pro endpoint settings.
		 *
		 * @param array $endpoints Endpoints.
		 *
		 * @return array
		 */
		public function wkmp_pro_add_endpoint_settings( $endpoints = array() ) {
			global $wkmarketplace;

			$wc_endpoints     = $wkmarketplace->wkmp_get_wc_registered_endpoints();
			$seller_shippings = in_array( 'seller-shippings', $wc_endpoints, true ) ? esc_attr( 'wkmp-shippings' ) : esc_attr( 'seller-shippings' );
			$become_seller    = in_array( 'become-seller', $wc_endpoints, true ) ? esc_attr( 'wkmp-become-seller' ) : esc_attr( 'become-seller' );
			$admin_dashboard  = in_array( 'separate-dashboard', $wc_endpoints, true ) ? esc_attr( 'wkmp-separate-dashboard' ) : esc_attr( 'separate-dashboard' );

			$endpoints['_wkmp_shipping_endpoint']        = array(
				'slug'  => $seller_shippings,
				'title' => esc_html__( 'Shippings', 'wk-marketplace' ),
			);
			$endpoints['_wkmp_become_seller_endpoint']   = array(
				'slug'  => $become_seller,
				'title' => esc_html__( 'Become a Seller', 'wk-marketplace' ),
			);
			$endpoints['_wkmp_admin_dashboard_endpoint'] = array(
				'slug'  => $admin_dashboard,
				'title' => esc_html__( 'Admin Dashboard', 'wk-marketplace' ),
			);

			return $endpoints;
		}

		/**
		 * Allowed settings groups to be allowed by demo admin.
		 *
		 * @param array $setting_groups Setting groups.
		 *
		 * @hooked 'wk_allow_settings_update_to_demo_admin' filter hook.
		 *
		 * @return array
		 */
		public function wkmp_pro_add_settings_groups_for_demo_admin( $setting_groups ) {
			$setting_groups = ( empty( $setting_groups ) || ! is_array( $setting_groups ) ) ? array() : $setting_groups;
			array_push(
				$setting_groups,
				'option_page_capability_wkmp-endpoint-settings-group',
				'option_page_capability_wkmp-google-analytics-settings-group'
			);

			return $setting_groups;
		}

		/**
		 * Method wkmp_pro_add_email_options_to_translate
		 *
		 * @param array $email_options Email options.
		 *
		 * @hooked 'wcml_emails_options_to_translate' action hook.
		 *
		 * @return array
		 */
		public function wkmp_pro_add_email_options_to_translate( $email_options ) {
			$email_options = is_array( $email_options ) ? $email_options : array();

			$email_options[] = 'woocommerce_wkmp_ask_to_admin_settings';
			$email_options[] = 'woocommerce_wkmp_customer_become_seller_to_admin_settings';
			$email_options[] = 'woocommerce_wkmp_customer_become_seller_settings';
			$email_options[] = 'woocommerce_wkmp_product_approve_disapprove_settings';
			$email_options[] = 'woocommerce_wkmp_seller_published_product_settings';
			$email_options[] = 'woocommerce_wkmp_seller_account_approved_settings';
			$email_options[] = 'woocommerce_wkmp_seller_account_disapproved_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_paid_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_cancelled_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_completed_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_failed_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_on_hold_settings';
			$email_options[] = 'woocommerce_wkmp_seller_product_ordered_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_processing_settings';
			$email_options[] = 'woocommerce_wkmp_seller_order_refunded_settings';
			$email_options[] = 'woocommerce_wkmp_seller_query_replied_settings';
			$email_options[] = 'woocommerce_wkmp_new_seller_registration_to_admin_settings';
			$email_options[] = 'woocommerce_wkmp_registration_details_to_seller_settings';
			$email_options[] = 'woocommerce_wkmp_seller_to_shop_followers_settings';

			return $email_options;
		}

		/**
		 * Show admin notices for different purposes.
		 *
		 * @return void
		 */
		public function wkmp_pro_maybe_show_addons_promotion_notices() {
			$wk_page = \WK_Caching::wk_get_request_data( 'page' );

			if ( ! empty( $wk_page ) && 0 === stripos( $wk_page, 'wk-marketplace' ) ) {
				?>
			<div data-admin_id="<?php echo esc_attr( get_current_user_id() ); ?>" class="wkmp-toast-notice promote_addons notice notice-info is-dismissible wkmp-hide">

				<section class="toast">
					<div class="upgrade-toast-wrap">
						<div class="upgrade-toast-content">
							<div class="upgrade-toast-box">
								<span class="upgrade-toast-icon"></span>
								<p class="upgrade-toast-content"><?php esc_html_e( 'Thank you for choosing Multivendor Marketplace for WooCommerce. You can also get more exclusive features via our', 'wk-marketplace' ); ?></p>
							</div>
							<a href="<?php echo esc_url( admin_url( 'admin.php?page=wk-marketplace-extensions&ext_tab=3' ) ); ?>" class="upgr-toast-btn"><?php esc_html_e( '50+ paid Marektplace Addons', 'wk-marketplace' ); ?></a>
						</div>
					</div>
				</section>
			</div>
				<?php
			}
		}

		/**
		 * Showing add new button on seller listing page.
		 *
		 * @hooked 'wkmp_after_seller_list_page_title' action hook.
		 *
		 * @return void
		 */
		public function wkmp_pro_add_new_seller_button() {
			?>
			<div class="wkmp-add-new-seller-form">
				<form method="post" action="<?php echo esc_url( admin_url( 'user-new.php' ) ); ?>">
					<input type="hidden" name="role" value="wk_marketplace_seller">
					<input type="hidden" name="createuser" value="yes">
					<input class="page-title-action" type="submit" value="<?php esc_attr_e( 'Add New', 'wk-marketplace' ); ?>">
				</form>
			</div>
			<?php
		}

		/**
		 * Creating a new seller from admin dashboard by admin.
		 *
		 * @param int   $user_id User id.
		 * @param array $userdata User data.
		 *
		 * @hooked 'user_register' action hook.
		 *
		 * @return void
		 */
		public function wkmp_pro_register_seller_from_admin( $user_id, $userdata ) {
			if ( 'wk_marketplace_seller' === $userdata['role'] ) {
				$commission_helper = HelperCommon\WKMP_Commission::get_instance();
				$query_handler     = Helper\WKMP_General_Queries::get_instance();

				$shop_name = \WK_Caching::wk_get_request_data( 'shopname', array( 'method' => 'post' ) );
				$store_url = \WK_Caching::wk_get_request_data( 'shopurl', array( 'method' => 'post' ) );
				$shop_name = wp_strip_all_tags( $shop_name );

				update_user_meta( $user_id, 'shop_name', $shop_name );
				update_user_meta( $user_id, 'shop_address', $store_url );

				$query_handler->wkmp_set_seller_meta( $user_id );
				$commission_helper->wkmp_set_seller_default_commission( $user_id );
			}
		}
	}
}
