<?php
/**
 * Admin End Hooks.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Admin;

defined( 'ABSPATH' ) || exit(); // Exit if access directly.

if ( ! class_exists( 'WKMP_Admin_Hooks_Pro' ) ) {

	/**
	 * Admin hooks class
	 */
	class WKMP_Admin_Hooks_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Admin hooks constructor.
		 *
		 * @return void
		 */
		public function __construct() {
			$handler = WKMP_Admin_Functions_Pro::get_instance();

			add_action( 'admin_init', array( $handler, 'wkmp_pro_register_marketplace_options' ) );
			add_action( 'admin_enqueue_scripts', array( $handler, 'wkmp_pro_admin_scripts' ) );
			add_action( 'wkmp_save_seller_commission', array( $handler, 'wkmp_pro_update_seller_commission' ), 10, 2 );
			add_action( 'wkmp_seller_misc_settings_saved', array( $handler, 'wkmp_pro_seller_misc_settings_update' ), 10, 2 );
			add_action( 'wkmp_pro_assign_product_to_seller', array( $handler, 'wkmp_pro_assign_products_to_seller' ) );
			add_action( 'wcml_emails_options_to_translate', array( $handler, 'wkmp_pro_add_email_options_to_translate' ), 11, 1 );
			add_action( 'admin_notices', array( $handler, 'wkmp_pro_maybe_show_addons_promotion_notices' ) );
			add_action( 'wkmp_after_seller_list_page_title', array( $handler, 'wkmp_pro_add_new_seller_button' ) );
			add_action( 'user_register', array( $handler, 'wkmp_pro_register_seller_from_admin' ), 10, 2 );

			add_filter( 'wkmp_pro_show_filtered_sellers_products', array( $handler, 'wkmp_pro_add_seller_filter_data' ) );
			add_filter( 'wkmp_feedback_rating_filter_data', array( $handler, 'wkmp_pro_add_search_filter_data' ) );
			add_filter( 'wkmp_admin_queries_filter_data', array( $handler, 'wkmp_pro_add_search_filter_data' ) );
			add_filter( 'wkmp_admin_seller_list_filter_data', array( $handler, 'wkmp_pro_add_search_filter_data' ) );
			add_filter( 'wkmp_endpoint_settings_array', array( $handler, 'wkmp_pro_add_endpoint_settings' ) );
			add_filter( 'wkmp_pro_admin_product_settings', array( $handler, 'wkmp_pro_admin_product_update_settings' ) );
			add_filter( 'wkmp_seller_misc_settings', array( $handler, 'wkmp_pro_update_seller_misc_settings' ) );
			add_filter( 'wk_allow_settings_update_to_demo_admin', array( $handler, 'wkmp_pro_add_settings_groups_for_demo_admin' ) );
			add_filter( 'wkmp_seller_commission_settings', array( $handler, 'wkmp_pro_update_seller_commission_settings' ) );
			add_filter( 'wkmp_seller_save_button_attributes', array( $handler, 'wkmp_pro_seller_save_button_attributes_enable' ) );
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}
	}
}
