<?php
/**
 * Main Pro Globals Class.
 *
 * @package Marketplace for WooCommerce
 *
 * @version 5.4.0
 */

namespace WkMarketplacePro\Includes;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMarketplace_Pro_Globals' ) ) {
	/**
	 * Marketplace Main Pro Class.
	 */
	class WKMarketplace_Pro_Globals {
		/**
		 * Instance variable.
		 *
		 * @var object
		 */
		protected static $wk = null;

		/**
		 * The object is created from within the class itself only if the class has no instance.
		 *
		 * @return object|WKMarketplace|null
		 */
		public static function get_instance() {
			if ( is_null( self::$wk ) ) {
				self::$wk = new self();
			}

			return self::$wk;
		}

		/**
		 * Marketplace Constructor.
		 */
		public function __construct() {
			$this->wkmp_init_hooks();
		}


		/**
		 * Hook into actions and filters.
		 *
		 * @return void|bool
		 */
		public function wkmp_init_hooks() {
		}

		/**
		 * Decide whether display seller registration fields are allowed are not.
		 *
		 * @return bool
		 */
		public function wkmp_allow_seller_registration_fields() {
			global $wkmarketplace;
			$display = false;

			$separate_reg_enabled = ( 1 === intval( get_option( '_wkmp_separate_seller_registration', false ) ) );

			if ( ( $separate_reg_enabled && ! is_account_page() && $wkmarketplace->wkmp_is_seller_page() ) || ( ! $separate_reg_enabled && ! is_user_logged_in() && ! $wkmarketplace->wkmp_is_seller_page() && is_account_page() ) ) {
				$display = true;
			}

			return $display;
		}
	}
}
