<?php
/**
 * Marketplace email class.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes;

use WkMarketplacePro\Includes\Emails;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMP_Emails_Pro' ) ) {
	/**
	 * Email handler class.
	 *
	 * Class WKMP_Emails_Pro
	 *
	 * @package WkMarketplacePro\Includes
	 */
	class WKMP_Emails_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Email handler constructor.
		 *
		 * WKMP_Emails constructor.
		 */
		public function __construct() {
			add_filter( 'woocommerce_email_classes', array( $this, 'wkmp_pro_add_new_email_notification' ), 10, 1 );
			add_filter( 'woocommerce_email_actions', array( $this, 'wkmp_pro_add_woocommerce_email_actions' ) );
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Marketplace Email classes.
		 *
		 * @param array $email Email.
		 *
		 * @return array $email
		 */
		public function wkmp_pro_add_new_email_notification( $email ) {
			$email['WC_Email_WKMP_Customer_Become_Seller']          = new Emails\WC_Email_WKMP_Customer_Become_Seller();
			$email['WC_Email_WKMP_Customer_Become_Seller_To_Admin'] = new Emails\WC_Email_WKMP_Customer_Become_Seller_To_Admin();

			return $email;
		}

		/**
		 * Marketplace Email action.
		 *
		 * @param array $actions Actions.
		 *
		 * @return array $actions
		 */
		public function wkmp_pro_add_woocommerce_email_actions( $actions ) {
			$actions[] = 'wkmp_customer_become_seller';
			$actions[] = 'wkmp_customer_become_seller_to_admin';

			return $actions;
		}
	}
}
