<?php
/**
 * File handler class.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplacePro\Includes\Front;
use WkMarketplacePro\Includes\Admin;
use WkMarketplacePro\Includes\Common;
use WkMarketplacePro\Separate_Dashboard as SellerDashboard;
use WkMarketplacePro\Templates\Front as FrontTemplates;

if ( ! class_exists( 'WKMP_File_Handler_Pro' ) ) {

	/**
	 * File handler class
	 */
	class WKMP_File_Handler_Pro {

		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * File handler constructor
		 */
		public function __construct() {

			if ( is_admin() ) {
				Admin\WKMP_Admin_Hooks_Pro::get_instance();
				Admin\WKMP_Admin_Ajax_Hooks_Pro::get_instance();
			} else {
				Front\WKMP_Front_Hooks_Pro::get_instance();
				FrontTemplates\WKMP_Front_Template_Hooks_Pro::get_instance();
			}

			WKMP_Emails_Pro::get_instance();
			Common\WKMP_Common_Hooks_Pro::get_instance();
			Front\WKMP_Front_Ajax_Hooks_Pro::get_instance();

			if ( get_option( '_wkmp_separate_seller_dashboard', false ) && get_user_meta( get_current_user_id(), 'wkmp_seller_backend_dashboard', true ) ) {
				SellerDashboard\WKMP_Seller_Backend_Hooks::get_instance();
			}
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}
	}
}
