<?php
/**
 * Marketplace email class.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplace\Helper\Admin as AdminHelper;

if ( ! class_exists( 'WKMP_Widget_Seller_Panel' ) ) {
	/**
	 * Class WKMP_Widget_Seller_Panel
	 */
	class WKMP_Widget_Seller_Panel extends WP_Widget {
		/**
		 * WKMP_Widget_Seller_Panel constructor.
		 */
		public function __construct() {
			parent::__construct(
				'mp_marketplace-widget',
				esc_html__( 'Display seller panel.', 'wk-marketplace' ),
				array(
					'classname'   => 'mp_marketplace',
					'description' => esc_html__( 'Marketplace Seller Panel.', 'wk-marketplace' ),
				)
			);
		}

		/**
		 * Widget data.
		 *
		 * @param array $args args.
		 * @param array $instance instance.
		 */
		public function widget( $args, $instance ) {
			global $wkmarketplace;

			$seller_db_obj = AdminHelper\WKMP_Seller_Data::get_instance();
			$user_id       = get_current_user_id();

			$seller_ids = $seller_db_obj->wkmp_get_sellers(
				array(
					'fields'     => 'mp.user_id',
					'role'       => 'seller',
					'seller_id'  => $user_id,
					'single_col' => true,
				)
			);

			$seller_id = ( is_iterable( $seller_ids ) && 1 === count( $seller_ids ) ) ? $seller_ids[0] : 0;

			if ( $seller_id > 0 ) {
				$page_name = $wkmarketplace->seller_page_slug;

				echo '<div class="wkmp_seller"><h2>' . esc_html__( 'Dashboard', 'wk-marketplace' );
				echo '</a></h2>';
				echo '<ul class="wkmp_sellermenu">';

				echo '<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_profile_endpoint', 'seller-profile' ) ) . '">';
				esc_html_e( 'My Profile', 'wk-marketplace' );
				echo '</a></li>
  							 <li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_add_product_endpoint', 'seller-add-product' ) ) . '">';
				esc_html_e( 'Add Product', 'wk-marketplace' );
				echo '</a></li>
  							<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_product_list_endpoint', 'seller-products' ) ) . '">';
				esc_html_e( 'Product List', 'wk-marketplace' );
				echo '</a></li>
  							<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_order_history_endpoint', 'sellers-orders' ) ) . '">';
				esc_html_e( 'Order History', 'wk-marketplace' );
				echo '</a></li>
  							<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ) ) . '">';
				esc_html_e( 'Manage Shipping', 'wk-marketplace' );
				echo '</a></li>';

				do_action( 'marketplace_list_seller_option', $page_name );

				echo '<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_shop_follower_endpoint', 'seller-shop-followers' ) ) . '">';
				esc_html_e( 'Shop Followers', 'wk-marketplace' );
				echo '</a></li>
  							<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_dashboard_endpoint', 'seller-dashboard' ) ) . '">';
				esc_html_e( 'Dashboard', 'wk-marketplace' );
				echo '</a></li>';
				echo '<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_asktoadmin_endpoint', 'seller-asktoadmin' ) ) . '">';
				esc_html_e( 'Ask To Admin', 'wk-marketplace' );
				echo '</a></li></ul></div>';
			}

			if ( $user_id > 0 && $seller_id < 1 ) {
				echo '<div class="wkmp_seller"><h2>' . esc_html__( 'Buyer Menu', 'wk-marketplace' ) . '</h2>';
				echo '<ul class="wkmp_sellermenu">';
				echo '<li class="wkmp-selleritem"><a href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_profile_endpoint', 'seller-profile' ) . '' ) . '">';
				esc_html_e( 'My Profile', 'wk-marketplace' );
				echo '</a></li></ul></div>';
			}
		}
	}
}
