<?php
/**
 * Front ajax functions Pro.
 *
 * @package Marketplace for WooCommerce
 *
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Front;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMP_Front_Ajax_Functions_Pro' ) ) {
	/**
	 * Front ajax functions Pro.
	 */
	class WKMP_Front_Ajax_Functions_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Add shipping Class.
		 */
		public function wkmp_pro_add_shipping_class() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {

				$data = empty( $_POST['data'] ) ? '' : $_POST['data'];

				$final_data = array();
				$arr        = array();
				$new_arr    = array();

				$json = array(
					'redirect' => '',
					'success'  => false,
				);

				parse_str( $data, $final_data );

				$final_data = empty( $final_data ) ? array() : $final_data;
				$updated    = 'error';

				foreach ( $final_data as $s_key => $s_value ) {
					$i = 0;
					$j = 0;
					foreach ( $s_value as $main_key => $main_value ) {
						if ( is_int( $main_key ) ) {
							$arr[ $i ][ $s_key ] = $main_value;
							++$i;
						} else {
							$new_arr[ $j ][ $s_key ] = $main_value;
							++$j;
						}
					}
				}

				foreach ( $arr as $arr_value ) {
					if ( array_key_exists( 'term_id', $arr_value ) ) {
						$updated = 'updated';
						wp_update_term( $arr_value['term_id'], 'product_shipping_class', $arr_value );
					}
				}

				$user_id = get_current_user_id();

				foreach ( $new_arr as $new_arr_value ) {
					if ( empty( $new_arr_value['name'] ) ) {
						$updated = 'empty-name';
						continue;
					}
					$term          = wp_insert_term( $new_arr_value['name'], 'product_shipping_class', $new_arr_value );
					$seller_sclass = get_user_meta( $user_id, 'shipping-classes', true );

					if ( ! empty( $seller_sclass ) ) {
						$seller_sclass = maybe_unserialize( $seller_sclass );
						array_push( $seller_sclass, $term['term_id'] );
						$seller_sclass_update = maybe_serialize( $seller_sclass );
						update_user_meta( $user_id, 'shipping-classes', $seller_sclass_update );
					} else {
						$term_arr   = array();
						$term_arr[] = $term['term_id'];
						$term_arr   = maybe_serialize( $term_arr );
						add_user_meta( $user_id, 'shipping-classes', $term_arr );
					}
					$updated = 'added';
				}

				$notice_data = array(
					'wkmp_ship_action' => $updated,
				);

				update_user_meta( $user_id, '_wkmp_shipping_notice_data', $notice_data );

				$json['redirect'] = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ) . '/add';
				wp_send_json( $json );
			}
		}

		/**
		 * Add shipping Cost to zone.
		 */
		public function wkmp_pro_seller_save_shipping_cost() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {
				$ship_cost  = empty( $_POST['ship_cost'] ) ? '' : wc_clean( $_POST['ship_cost'] );
				$final_data = array();
				parse_str( $ship_cost, $final_data );
				$instance_id     = empty( $final_data['instance_id'] ) ? 0 : absint( $final_data['instance_id'] );
				$shipping_method = \WC_Shipping_Zones::get_shipping_method( $instance_id );
				$shipping_method->set_post_data( $final_data );
				$shipping_method->process_admin_options();
				die;
			}
		}

		/**
		 * Delete shipping Class.
		 */
		public function wkmp_pro_seller_delete_shipping_class() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {
				$term_id = empty( $_POST['get-term'] ) ? 0 : intval( wp_unslash( $_POST['get-term'] ) );

				$resp = array( 'success' => true );

				if ( ! empty( $term_id ) ) {
					$user_id         = get_current_user_id();
					$term_id         = $term_id;
					$res             = wp_delete_term( $term_id, 'product_shipping_class' );
					$resp['success'] = $res;

					$notice_data = array(
						'wkmp_ship_action' => 'deleted',
					);
					update_user_meta( $user_id, '_wkmp_shipping_notice_data', $notice_data );
					$resp['redirect'] = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ) . '/add';

				}
				wp_send_json( $resp );
			}
		}

		/**
		 * Add shipping method to zone.
		 */
		public function wkmp_pro_seller_add_shipping_method() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {
				$zone_id = empty( $_POST['zone-id'] ) ? 0 : intval( wp_unslash( $_POST['zone-id'] ) );

				$zone_status = $this->wkmp_pro_is_valid_seller_zone_id( $zone_id );
				$confirm     = 'unauthorized';

				if ( $zone_status ) {
					$ship_method  = empty( $_POST['ship-method'] ) ? 0 : wc_clean( wp_unslash( $_POST['ship-method'] ) );
					$current_zone = new \WC_Shipping_Zone( $zone_id );
					$confirm      = $current_zone->add_shipping_method( $ship_method );
				}

				$result = array( 'success' => $confirm );
				wp_send_json( $result );
			}
		}

		/**
		 * Get seller id base on zone.
		 *
		 * @param int $zon_id zone id.
		 *
		 * @return bool
		 */
		public function wkmp_pro_is_valid_seller_zone_id( $zon_id ) {
			global $wpdb;

			$wpdb_obj    = $wpdb;
			$get_data    = $wpdb_obj->get_row( $wpdb_obj->prepare( "Select * from {$wpdb_obj->prefix}mpseller_meta where zone_id = %d ", $zon_id ) );
			$zon_user_id = empty( $get_data->seller_id ) ? 0 : intval( $get_data->seller_id );
			$seller_id   = get_current_user_id();

			if ( $seller_id === $zon_user_id ) {
				return true;
			}

			return false;
		}

		/**
		 * Delete Shipping Method.
		 */
		public function wkmp_pro_delete_shipping_method() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {
				global $wpdb;

				$result     = array( 'success' => false );
				$wpdb_obj   = $wpdb;
				$table_name = $wpdb_obj->prefix . 'woocommerce_shipping_zone_methods';
				$zone_id    = empty( $_POST['zone-id'] ) ? 0 : intval( wp_unslash( $_POST['zone-id'] ) );

				$zone_status = $this->wkmp_pro_is_valid_seller_zone_id( $zone_id );

				if ( $zone_status ) {
					$instance_id = empty( $_POST['instance-id'] ) ? 0 : intval( wp_unslash( $_POST['instance-id'] ) );
					$res         = $wpdb_obj->get_row( $wpdb_obj->prepare( "SELECT method_id FROM {$wpdb_obj->prefix}woocommerce_shipping_zone_methods WHERE zone_id = %d AND instance_id = %d", $zone_id, $instance_id ) );

					$response = $wpdb_obj->delete(
						$table_name,
						array(
							'zone_id'     => $zone_id,
							'instance_id' => $instance_id,
						),
						array( '%d' )
					);

					if ( $response ) {
						delete_option( 'woocommerce_' . $res->method_id . '_' . $instance_id . '_settings' );
						$result['success'] = true;
					}
				} else {
					$result['success'] = false;
				}

				wp_send_json( $result );
			}
		}

		/**
		 * Delete Zone details list Ajax.
		 */
		public function wkmp_pro_delete_zone() {
			if ( check_ajax_referer( 'wkmp-front-nonce', 'wkmp_nonce', false ) && current_user_can( 'wk_marketplace_seller' ) ) {
				global $wpdb;
				$wpdb_obj          = $wpdb;
				$current_seller_id = get_current_user_id();
				$zone_id           = empty( $_POST['zone-id'] ) ? 0 : intval( wp_unslash( $_POST['zone-id'] ) );

				$json    = array();
				$deleted = false;

				if ( ! empty( $zone_id ) ) {
					$zone_seller_id = $wpdb_obj->get_var( $wpdb_obj->prepare( "SELECT `seller_id` FROM {$wpdb_obj->prefix}mpseller_meta WHERE zone_id = %d", $zone_id ) );
					if ( intval( $zone_seller_id ) === $current_seller_id ) {
						// Using where formatting.
						$zone      = \WC_Shipping_Zones::get_zone( $zone_id );
						$zone_name = $zone->get_data()['zone_name'];

						$wpdb_obj->delete( $wpdb_obj->prefix . 'mpseller_meta', array( 'zone_id' => $zone_id ), array( '%d' ) );
						\WC_Shipping_Zones::delete_zone( $zone_id );

						$notice_data = array(
							'action'    => 'Deleted',
							'zone_name' => $zone_name,
						);
						update_user_meta( $current_seller_id, '_wkmp_shipping_notice_data', $notice_data );
						$deleted = true;
					}
				}

				if ( $deleted ) {
					$json['message']  = esc_html__( 'Shipping zone has been deleted.', 'wk-marketplace' );
					$json['redirect'] = wc_get_endpoint_url( get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ), '', wc_get_page_permalink( 'myaccount' ) );
				} else {
					$msg             = esc_html__( 'You are not allowed to delete this shipping zone.', 'wk-marketplace' );
					$json['message'] = $msg;
					wc_add_notice( $msg, 'error' );
				}

				wp_send_json( $json );
			}
		}
	}
}
