<?php
/**
 * Front functions template
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Front;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplace\Includes\Common;

if ( ! class_exists( 'WKMP_Front_Functions_Pro' ) ) {
	/**
	 * Front functions class
	 */
	class WKMP_Front_Functions_Pro {
		/**
		 * Constructor of the class.
		 *
		 * WKMP_Front_Functions constructor.
		 */
		public function __construct() {
		}

		/**
		 * Front Scripts Enqueue
		 *
		 * @hooked 'wp_enqueue_scripts' Action hook.
		 *
		 * @return void
		 */
		public function wkmp_pro_front_scripts() {
			global $wkmarketplace, $wp;
			$query_vars = $wp->query_vars;

			if ( $wkmarketplace->wkmp_is_woocommerce_page() || $wkmarketplace->wkmp_is_seller_page( $query_vars ) ) {
				$suffix     = ( defined( 'WKWC_DEV' ) && true === WKWC_DEV ) ? '' : '.min';
				$asset_path = ( defined( 'WKWC_DEV' ) && true === WKWC_DEV ) ? 'build' : 'dist';

				wp_enqueue_style( 'wkmp-pro-front-style-css', WKMP_PLUGIN_URL . 'assets/' . $asset_path . '/front/css/wkmp-pro-front' . $suffix . '.css', array(), WKMP_SCRIPT_VERSION );
				wp_enqueue_script( 'wkmp-pro-front-script', WKMP_PLUGIN_URL . 'assets/' . $asset_path . '/front/js/front' . $suffix . '.js', array(), WKMP_SCRIPT_VERSION, true );
			}
		}


		/**
		 * Seller endpoints.
		 *
		 * @hooked 'init' action Hook.
		 *
		 * @return void
		 */
		public function wkmp_pro_create_wc_seller_endpoints() {
			$endpoints = array(
				get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ),
				get_option( '_wkmp_become_seller_endpoint', 'become-seller' ),
			);

			foreach ( $endpoints as $endpoint ) {
				add_rewrite_endpoint( $endpoint, EP_ROOT | EP_PAGES );
			}

			flush_rewrite_rules( false );
		}

		/**
		 * Add seller menu items in my account menu
		 *
		 * @param array $items items array.
		 *
		 * @hooked 'wkmp_pro_woocommerce_account_menu_options' filter hook.
		 *
		 * @return array
		 */
		public function wkmp_pro_seller_my_account_menu_items( $items ) {
			global $wkmarketplace;
			$user_id = get_current_user_id();

			if ( $user_id > 0 && $wkmarketplace->wkmp_user_is_seller( $user_id ) ) {
				$check = get_option( 'wkmp_shipping_option', 'woocommerce' );

				if ( 'marketplace' === $check && 'disabled' !== get_option( 'woocommerce_ship_to_countries', false ) ) {
					$items[ get_option( '_wkmp_shipping_endpoint', 'seller-shippings' ) ] = esc_html( get_option( '_wkmp_shipping_endpoint_name', esc_html__( 'Shippings', 'wk-marketplace' ) ) );
				}
			}

			return $items;
		}

		/**
		 * Add 'Admin Dashboard' seller menu in my account menu
		 *
		 * @param array $items items array.
		 *
		 * @hooked 'wkmp_pro_wc_account_menu_items' filter hook.
		 *
		 * @return array
		 */
		public function wkmp_pro_seller_add_admin_dashaboard_menu( $items ) {
			global $wkmarketplace;
			$user_id = get_current_user_id();

			if ( $user_id > 0 && $wkmarketplace->wkmp_user_is_seller( $user_id ) ) {

				if ( 1 === intval( get_option( '_wkmp_separate_seller_dashboard', false ) ) ) {
					$separate_dashboard = get_option( '_wkmp_admin_dashboard_endpoint', 'separate-dashboard' );

					$items[ '../' . $separate_dashboard ] = get_option( '_wkmp_admin_dashboard_endpoint_name', esc_html__( 'Admin Dashboard', 'wk-marketplace' ) );
				}
			}

			return $items;
		}

		/**
		 * Returning Google account number if it is enabled.
		 *
		 * @return false|mixed|void
		 */
		public function wkmp_pro_get_ga_number() {
			$enabled   = get_option( '_wkmp_enable_google_analytics', false );
			$ga_number = get_option( '_wkmp_google_account_number', false );

			return ( $enabled ) ? $ga_number : false;
		}

		/**
		 * Storing data into WC session for rendering on woocommerce thank you.
		 *
		 * @hooked woocommerce_checkout_order_processed
		 *
		 * @param int       $order_id Order id.
		 * @param array     $posted_data Posted data.
		 * @param \WC_Order $order Order object.
		 */
		public function wkmp_pro_collect_order_data_for_ga( $order_id, $posted_data, $order ) {
			$ga_tracking_number = $this->wkmp_pro_get_ga_number();
			if ( ! empty( $ga_tracking_number ) && ! empty( $order_id ) ) {
				$order            = ( $order instanceof \WC_Order ) ? $order : wc_get_order( $order_id );
				$order_id         = $order->get_id();
				$ga_products      = array();
				$common_functions = Common\WKMP_Common_Functions::get_instance();
				$items            = $order->get_items( 'line_item' );

				foreach ( $items as $item ) {
					$prod_id = $item->get_product_id();
					$product = wc_get_product( $prod_id );
					if ( $product instanceof \WC_product ) {
						$category_ids   = $product->get_category_ids();
						$category_name  = '';
						$category_names = array();

						if ( is_array( $category_ids ) && count( $category_ids ) > 0 ) {
							$category_id = $category_ids[0];
							if ( is_numeric( $category_id ) && $category_id > 0 ) {
								$cat_term = get_term_by( 'id', $category_id, 'product_cat' );
								if ( $cat_term ) {
									$category_name    = $cat_term->name;
									$category_names[] = $category_name;
								}
							}
						}

						$post_author = get_post_field( 'post_author', $prod_id );
						$shop_name   = get_user_meta( $post_author, 'shop_name', true );
						$brand       = empty( $shop_name ) ? get_bloginfo( 'name' ) : $shop_name;

						$ga_products[ $prod_id ] = array_map(
							'html_entity_decode',
							array(
								'id'       => $prod_id,
								'sku'      => $common_functions->wkmp_get_sku( $product ),
								'category' => implode( ',', $category_names ),
								'name'     => $product->get_title() . '(' . $post_author . ')',
								'quantity' => $item->get_quantity(),
								'price'    => $order->get_item_subtotal( $item ),
								'currency' => $order->get_currency(),
								'brand'    => $brand,
								'position' => $post_author,
								'variant'  => $product->get_type(),
							)
						);
					}
				}

				$ga_data = array(
					'products'    => $ga_products,
					'transaction' => array(
						'id'          => $order_id,
						'affiliation' => esc_attr( get_bloginfo( 'name' ) ),
						'revenue'     => $order->get_total(),
						'shipping'    => $order->get_shipping_total(),
						'tax'         => $order->get_total_tax(),
						'currency'    => $order->get_currency(),
					),
				);

				$cookie_key = '_wkmp_google_analytics_data';
				setcookie( $cookie_key, base64_encode( wp_json_encode( $ga_data ) ), time() + ( 30 * 24 * 3600 ), '/' ); //phpcs:ignore WordPressVIPMinimum.Functions.RestrictedFunctions.cookies_setcookie
				$_COOKIE[ $cookie_key ] = $ga_data; //phpcs:ignore WordPressVIPMinimum.Variables.RestrictedVariables.cache_constraints___COOKIE

				wkmp_wc_log( "Google analytics data collected for order id: $order_id" );
			}
		}

		/**
		 * Adding Google analytics scripts for tracking.
		 */
		public function wkmp_pro_add_ga_script() {
			global $post;

			$ga_tracking_number = $this->wkmp_pro_get_ga_number();

			if ( ! empty( $ga_tracking_number ) ) {
				$post_id      = isset( $post->ID ) ? $post->ID : 0;
				$post_title   = isset( $post->post_title ) ? $post->post_title : 'NA';
				$anonymize_ip = get_option( '_wkmp_analytics_anonymize_ip', false );
				$anonymize_ip = $anonymize_ip ? '1' : '0';
				wkmp_wc_log( "Google analytics data sending page view with ID: $post_id, Post title: $post_title, for tracking number: $ga_tracking_number, anonymize_ip: $anonymize_ip" );
				?>
				<!-- Google Analytics Script -->
				<script>
					(function (i, s, o, g, r, a, m) {
						i['GoogleAnalyticsObject'] = r;
						i[r] = i[r] || function () {
							(i[r].q = i[r].q || []).push(arguments)
						}, i[r].l = 1 * new Date();
						a = s.createElement(o),
							m = s.getElementsByTagName(o)[0];
						a.async = 1;
						a.src = g;
						m.parentNode.insertBefore(a, m)
					})(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');
				</script>
				<script>
					ga('create', '<?php echo esc_attr( $ga_tracking_number ); ?>', 'auto');
					ga('set', 'userId', <?php echo esc_attr( get_current_user_id() ); ?>);
					ga('set', 'anonymizeIp', <?php echo esc_attr( $anonymize_ip ); ?>);
					<?php esc_js( $this->print_ga_advanced_tracking_code() ); ?>
					ga('send', 'pageview');
				</script>
				<?php
			}
		}

		/**
		 * Printing Google analytics code on thank you page.
		 */
		public function print_ga_advanced_tracking_code() {
			if ( is_checkout() && ! empty( is_wc_endpoint_url( 'order-received' ) ) ) {
				$cookie_key = '_wkmp_google_analytics_data';
				$ga_data    = isset( $_COOKIE[ $cookie_key ] ) ? base64_decode( $_COOKIE[ $cookie_key ] ) : 0; //phpcs:ignore WordPressVIPMinimum.Variables.RestrictedVariables.cache_constraints___COOKIE

				$ga_data = empty( $ga_data ) ? array() : json_decode( $ga_data, true );

				if ( ! empty( $ga_data ) ) {
					file_get_contents( WKMP_PLUGIN_FILE . 'templates/front/tracking-blocks/wkmp-ga-codes.phtml' ); //phpcs:ignore WordPressVIPMinimum.Files.IncludingNonPHPFile.IncludingNonPHPFile
					$ga_data = array();
					setcookie( $cookie_key, base64_encode( wp_json_encode( $ga_data ) ), time() + ( 30 * 24 * 3600 ), '/' ); //phpcs:ignore WordPressVIPMinimum.Functions.RestrictedFunctions.cookies_setcookie
					$_COOKIE[ $cookie_key ] = $ga_data;
				}
			}
		}

		/**
		 * Method wkmp_cart_shipping_packages
		 *
		 * @param array $packages Shipping packages.
		 *
		 * @return array
		 */
		public function wkmp_pro_cart_shipping_packages( $packages ) {
			global $wkmarketplace;

			$vendor_items = array();
			$product_ids  = array();

			foreach ( $packages as $package ) {
				if ( ! empty( $package['contents'] ) && is_array( $package['contents'] ) ) {
					foreach ( $package['contents'] as $content ) {
						$product_ids[] = empty( $content['product_id'] ) ? 0 : $content['product_id'];
					}
				}
			}

			foreach ( WC()->cart->get_cart() as $item ) {
				$product_id = intval( $item['product_id'] );
				if ( ! in_array( $product_id, array_map( 'intval', $product_ids ), true ) ) {
					continue;
				}
				$author = get_post_field( 'post_author', $product_id );

				if ( ! $wkmarketplace->wkmp_user_is_seller( $author ) ) {
					$first_admin_id = $wkmarketplace->wkmp_get_first_admin_user_id();

					$vendor_items[ $first_admin_id ][ $product_id ] = $item;
				} else {
					$vendor_items[ $author ][ $product_id ] = $item;
				}
			}

			$packages = array();

			foreach ( $vendor_items as $items ) {
				$packages[] = array(
					'contents'        => $items,
					'contents_cost'   => array_sum( wp_list_pluck( $items, 'line_total' ) ),
					'applied_coupons' => WC()->cart->applied_coupons,
					'destination'     => array(
						'country'   => WC()->customer->get_shipping_country(),
						'state'     => WC()->customer->get_shipping_state(),
						'postcode'  => WC()->customer->get_shipping_postcode(),
						'city'      => WC()->customer->get_shipping_city(),
						'address'   => WC()->customer->get_shipping_address(),
						'address_2' => WC()->customer->get_shipping_address_2(),
					),
				);
			}

			return $packages;
		}

		/**
		 * Method wkmp_change_package_name
		 *
		 * @param string $package_name Package name.
		 * @param array  $idx Ids array.
		 * @param array  $package Package.
		 *
		 * @hooked 'woocommerce_shipping_package_name' Filter hook.
		 *
		 * @return string
		 */
		public function wkmp_pro_change_package_name( $package_name, $idx, $package ) {
			global $wkmarketplace;

			$chosen_ship_methods = WC()->session->get( 'chosen_shipping_methods' );

			if ( ! empty( $package['contents'] ) ) {
				$product_ids      = array_keys( $package['contents'] );
				$first_product_id = count( $product_ids ) > 0 ? $product_ids[0] : 0;

				if ( $first_product_id > 0 ) {
					$post_author  = get_post_field( 'post_author', $first_product_id );
					$is_seller    = $wkmarketplace->wkmp_user_is_seller( $post_author );
					$seller_name  = $is_seller ? get_user_meta( $post_author, 'shop_name', true ) : esc_html__( 'Admin', 'wk-marketplace' );
					$package_name = wp_sprintf( /* Translators: %s: Seller name. */ esc_html__( 'Shipping: %s', 'wk-marketplace' ), $seller_name );

					if ( ! empty( $package['rates'] ) ) {
						$custom_shipping_list   = WC()->session->get( 'wkmp_custom_shipping_list', array() );
						$custom_chosen_shipping = WC()->session->get( 'wkmp_custom_chosen_shipping', array() );

						if ( $idx < 1 ) {
							$custom_shipping_list   = array();
							$custom_chosen_shipping = array();
						}

						foreach ( $package['rates'] as $shipping_id => $shipping_rate ) {
							$custom_shipping_list[ $shipping_id . '_' . $post_author ] = $shipping_rate->get_cost();
						}

						WC()->session->set( 'wkmp_custom_shipping_list', $custom_shipping_list );

						$custom_chosen_shipping[ $chosen_ship_methods[ $idx ] . '_' . $post_author ] = array(
							'cost'  => $custom_shipping_list[ $chosen_ship_methods[ $idx ] . '_' . $post_author ],
							'title' => $chosen_ship_methods[ $idx ],
						);

						WC()->session->set( 'wkmp_custom_chosen_shipping', $custom_chosen_shipping );
					}
				}
			}

			return $package_name;
		}

		/**
		 * Method wkmp_custom_shipping_in_session
		 *
		 * @param array $ship_sess Shipping session.
		 *
		 * @hooked 'wk_mp_modify_shipping_session' filter hook.
		 *
		 * @return array
		 */
		public function wkmp_pro_custom_shipping_in_session( $ship_sess ) {
			$custom_chosen_shipping = WC()->session->get( 'wkmp_custom_chosen_shipping', array() );
			$ship_sess              = empty( $custom_chosen_shipping ) ? $ship_sess : $custom_chosen_shipping;
			WC()->session->__unset( 'wkmp_custom_chosen_shipping' );
			WC()->session->__unset( 'wkmp_custom_shipping_list' );

			return $ship_sess;
		}

		/**
		 * Method wkwc_extract_numeric_seller_id
		 *
		 * @param string $sess_seller_id Seller id.
		 *
		 * @return int
		 */
		public function wkmp_pro_extract_numeric_seller_id( $sess_seller_id ) {
			if ( ! is_numeric( $sess_seller_id ) ) {
				$sess_seller_keys = explode( '_', $sess_seller_id );
				$sess_seller_id   = empty( $sess_seller_keys ) ? 0 : end( $sess_seller_keys );
			}

			return $sess_seller_id;
		}

		/**
		 * Method wkmp_add_shipping_item_meta
		 *
		 * @param Object    $item item.
		 * @param string    $package_key Package key.
		 * @param array     $package Shipping package.
		 * @param \WC_Order $order  Order object.
		 *
		 * @hooked 'woocommerce_checkout_create_order_shipping_item' Action hook.
		 *
		 * @return void
		 */
		public function wkmp_pro_add_shipping_item_meta( $item, $package_key, $package, $order ) {
			global $wkmarketplace;

			if ( ! empty( $package['contents'] ) ) {
				$product_ids      = array_keys( $package['contents'] );
				$first_product_id = count( $product_ids ) > 0 ? $product_ids[0] : 0;

				if ( $first_product_id > 0 ) {
					$post_author = get_post_field( 'post_author', $first_product_id );
					$is_seller   = $wkmarketplace->wkmp_user_is_seller( $post_author );

					if ( $is_seller ) {
						$shop_name = get_user_meta( $post_author, 'shop_name', true );

						if ( empty( $shop_name ) ) {
							$first_name = get_user_meta( $post_author, 'first_name', true );
							$first_name = empty( $first_name ) ? get_user_meta( $post_author, 'billing_first_name', true ) : $first_name;
							$first_name = empty( $first_name ) ? get_user_meta( $post_author, 'shipping_first_name', true ) : $first_name;

							if ( ! empty( $first_name ) ) {
								$last_name = get_user_meta( $post_author, 'last_name', true );
								$last_name = empty( $last_name ) ? get_user_meta( $post_author, 'billing_last_name', true ) : $last_name;
								$last_name = empty( $last_name ) ? get_user_meta( $post_author, 'shipping_last_name', true ) : $last_name;

								$shop_name = $first_name . ' ' . $last_name;
							}
						}
						$item->update_meta_data( 'Store name', $shop_name );
						$item->update_meta_data( '_wkmp_seller_id', $post_author );
					}
				}
			}
		}
	}
}
