<?php
/**
 * Front hooks template
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Includes\Front;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplacePro\Templates\Front\Seller;
use WkMarketplacePro\Templates\Front as FrontTemplates;

if ( ! class_exists( 'WKMP_Front_Hooks_Pro' ) ) {
	/**
	 * Front hooks class.
	 *
	 * Class WKMP_Front_Hooks
	 *
	 * @package WkMarketplace\Includes\Front
	 */
	class WKMP_Front_Hooks_Pro {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Constructor.
		 */
		public function __construct() {
			$seller_id   = get_current_user_id();
			$seller_user = get_user_by( 'ID', $seller_id );

			$template_handler = FrontTemplates\WKMP_Front_Template_Functions_Pro::get_instance();
			$function_handler = new WKMP_Front_Functions_Pro( $template_handler );

			add_action( 'init', array( $function_handler, 'wkmp_pro_create_wc_seller_endpoints' ) );

			add_action( 'wp_enqueue_scripts', array( $function_handler, 'wkmp_pro_front_scripts' ) );

			add_action( 'wp_head', array( $function_handler, 'wkmp_pro_add_ga_script' ) );
			add_action( 'woocommerce_checkout_order_processed', array( $function_handler, 'wkmp_pro_collect_order_data_for_ga' ), 10, 3 );

			if ( is_a( $seller_user, 'WP_User' ) && in_array( 'wk_marketplace_seller', $seller_user->roles, true ) ) {
				$seller_template = Seller\WKMP_Seller_Template_Functions_Pro::get_instance();
				add_filter( 'wkmp_pro_woocommerce_account_menu_options', array( $function_handler, 'wkmp_pro_seller_my_account_menu_items' ) );
				add_filter( 'wkmp_pro_wc_account_menu_items', array( $function_handler, 'wkmp_pro_seller_add_admin_dashaboard_menu' ) );

				$shippings = get_option( '_wkmp_shipping_endpoint', 'seller-shippings' );
				add_action( 'woocommerce_account_' . $shippings . '_endpoint', array( $seller_template, 'wkmp_pro_shippings_content' ) );
			}

			if ( 'marketplace' === get_option( 'wkmp_shipping_option', 'woocommerce' ) ) {
				add_filter( 'woocommerce_cart_shipping_packages', array( $function_handler, 'wkmp_pro_cart_shipping_packages' ) );
				add_filter( 'woocommerce_shipping_package_name', array( $function_handler, 'wkmp_pro_change_package_name' ), 999, 3 );
				add_filter( 'wk_mp_modify_shipping_session', array( $function_handler, 'wkmp_pro_custom_shipping_in_session' ) );
				add_filter( 'wkmp_shipping_session_seller_id', array( $function_handler, 'wkmp_pro_extract_numeric_seller_id' ), 10, 1 );
				add_filter( 'woocommerce_checkout_create_order_shipping_item', array( $function_handler, 'wkmp_pro_add_shipping_item_meta' ), 10, 4 );
			}
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}
	}
}
