<?php
/**
 * MP Lite Dependency checker class.
 *
 * @package Marketplace for WooCommerce
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * MP Lite Dependency Checker
 *
 * Checks if MP Lite is enabled.
 *
 * @package Marketplace for WooCommerce
 */
class WKMP_Lite_Dependencies {
	/**
	 * Private static Active plugins.
	 *
	 * @var array $active_plugins
	 */
	private static $active_plugins;

	/**
	 * Init function.
	 *
	 * @return void
	 */
	public static function init() {
		self::$active_plugins = (array) get_option( 'active_plugins', array() );

		if ( is_multisite() ) {
			self::$active_plugins = array_merge( self::$active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
		}
	}

	/**
	 * MP Lite active check.
	 *
	 * @return bool
	 */
	public static function wkmp_lite_install_check() {
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$installed_plugins = get_plugins();

		return isset( $installed_plugins[ WKMP_LITE_PLUGIN_BASENAME ] );
	}

	/**
	 * MP Lite active check.
	 *
	 * @return bool
	 */
	public static function wkmp_lite_active_check() {
		if ( ! self::$active_plugins ) {
			self::init();
		}

		return in_array( WKMP_LITE_PLUGIN_BASENAME, self::$active_plugins, true ) || array_key_exists( WKMP_LITE_PLUGIN_BASENAME, self::$active_plugins );
	}

	/**
	 * MP Lite Minimum required version check.
	 *
	 * @return bool
	 */
	public static function wkmp_lite_min_version_check() {
		if ( ! defined( 'WKMP_LITE_VERSION' ) ) {
			return false;
		}

		if ( ! version_compare( WKMP_LITE_VERSION, WKMP_LITE_MIN_VERSION, '>=' ) ) {
			return false;
		}

		return true;
	}
}
