<?php
/**
 * Seller back end order list.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Separate_Dashboard;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

if ( ! class_exists( 'WKMP_Seller_Backend_Order_List' ) ) {

	/**
	 * Class WKMP_Seller_Backend_Order_List
	 *
	 * @package WkMarketplace\Separate_Dashboard
	 */
	class WKMP_Seller_Backend_Order_List extends \WP_List_Table {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * WKMP_Seller_Backend_Order_List constructor.
		 */
		public function __construct() {
			parent::__construct(
				array(
					'singular' => 'order',
					'plural'   => 'orders',
					'ajax'     => false,
				)
			);
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Prepare items.
		 *
		 * @param string $search Search keyword.
		 */
		public function prepare_items( $search = '' ) {
			$columns     = $this->get_columns();
			$sortable    = $this->get_sortable_columns();
			$hidden      = $this->get_hidden_columns();
			$final_data  = $this->table_data( $search );
			$data        = empty( $final_data['data'] ) ? array() : $final_data['data'];
			$total_items = empty( $final_data['total_orders'] ) ? 0 : $final_data['total_orders'];

			$per_page              = $this->get_items_per_page( 'order_per_page', 20 );
			$this->_column_headers = array( $columns, $hidden, $sortable );
			$total_pages           = ceil( $total_items / $per_page );

			$this->set_pagination_args(
				array(
					'total_items' => $total_items,
					'total_pages' => $total_pages,
					'per_page'    => $per_page,
				)
			);

			$this->items = $data;
		}

		/**
		 * Hidden columns.
		 *
		 * @return array
		 */
		public function get_hidden_columns() {
			return array();
		}

		/**
		 * Get columns.
		 *
		 * @return array
		 */
		public function get_columns() {
			return array(
				'order_id'     => esc_html__( 'Order', 'wk-marketplace' ),
				'order_status' => esc_html__( 'Status', 'wk-marketplace' ),
				'order_date'   => esc_html__( 'Date', 'wk-marketplace' ),
				'order_total'  => esc_html__( 'Total', 'wk-marketplace' ),
				'action'       => esc_html__( 'Action', 'wk-marketplace' ),
			);
		}

		/**
		 * Get sortable columns.
		 *
		 * @return array[]
		 */
		public function get_sortable_columns() {
			return array( 'order_id' => array( 'order_id', true ) );
		}

		/**
		 * Default columns values.
		 *
		 * @param array  $item Order item.
		 * @param string $column_name Column name.
		 *
		 * @return bool|string
		 */
		public function column_default( $item, $column_name ) {
			switch ( $column_name ) {
				case 'order_id':
				case 'order_status':
				case 'order_date':
				case 'order_total':
				case 'action':
					return $item[ $column_name ];
				default:
					return '-';
			}
		}

		/**
		 * Table data.
		 *
		 * @param string $search Search.
		 *
		 * @return array
		 */
		private function table_data( $search ) {
			global $wkmarketplace;

			$orderby    = \WK_Caching::wk_get_request_data( 'orderby', array( 'default' => 'order_id' ) );
			$sort_order = \WK_Caching::wk_get_request_data( 'order', array( 'default' => 'desc' ) );

			$per_page = $this->get_items_per_page( 'order_per_page', 20 );
			$page_no  = $this->get_pagenum();
			$offset   = $per_page * ( $page_no - 1 );

			$filter_data = array(
				'user_id'    => get_current_user_id(),
				'search'     => $search,
				'order_by'   => $orderby,
				'sort_order' => $sort_order,
				'per_page'   => $per_page,
				'page_no'    => $page_no,
				'offset'     => $offset,
			);

			return $wkmarketplace->wkmp_get_seller_order_table_data( $filter_data );
		}
	}
}
