<?php
/**
 * Front hooks template.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Separate_Dashboard;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMP_Seller_Backend_Profile' ) ) {

	/**
	 * Class for backend seller profile.
	 */
	class WKMP_Seller_Backend_Profile {
		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Constructor of the class.
		 *
		 * WKMP_Seller_Backend_Profile constructor.
		 */
		public function __construct() {
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Display backend profile.
		 */
		public function wkmp_display_backend_profile() {
			global $wkmarketplace;

			$current_user_id = get_current_user_id();
			$posted_data     = array();

			$nonce = \WK_Caching::wk_get_request_data( 'wkmp-user-nonce', array( 'method' => 'post' ) );

			if ( ! empty( $nonce ) && wp_verify_nonce( $nonce, 'wkmp-user-nonce-action' ) && $current_user_id > 0 ) {
				$posted_data['about_shop']      = empty( $_POST['wkmp_about_shop'] ) ? '' : stripslashes( wp_kses_post( $_POST['wkmp_about_shop'] ) );
				$posted_data['wkmp_shop_phone'] = \WK_Caching::wk_get_request_data( 'wkmp_shop_phone', array( 'method' => 'post' ) );
				$result                         = $this->wkmp_profile_edit_redirection( $current_user_id, $posted_data );

				if ( isset( $result['success'] ) ) {
					echo '<div class="updated notice" style="margin-bottom: 10px;"><p>' . wp_kses_post( $result['success'] ) . '</p></div>';
				} elseif ( isset( $result['error'] ) ) {
					echo '<div class="error notice" style="margin-bottom: 10px;"><p>' . wp_kses_post( $result['error'] ) . '</p></div>';
				}
			}

			$page_name   = isset( $wkmarketplace->seller_page_slug ) ? $wkmarketplace->seller_page_slug : 'seller';
			$seller_info = $wkmarketplace->wkmp_get_parsed_seller_info( $current_user_id, $posted_data );

			require_once __DIR__ . '/wkmp-seller-backend-profile.php';
		}

		/**
		 * Profile edit redirection.
		 *
		 * @param int   $seller_id Seller id.
		 * @param array $posted_data Posted form data.
		 *
		 * @return array
		 */
		public function wkmp_profile_edit_redirection( $seller_id, $posted_data ) {
			$nonce = \WK_Caching::wk_get_request_data( 'wkmp-user-nonce', array( 'method' => 'post' ) );

			if ( ! empty( $nonce ) && wp_verify_nonce( $nonce, 'wkmp-user-nonce-action' ) ) {

				do_action( 'wkmp_validate_update_seller_profile', $posted_data, $seller_id );

				$errors = isset( $_POST['wkmp_errors'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_POST['wkmp_errors'] ) ) : array();

				if ( ! empty( $errors ) ) {
					$text = '';
					foreach ( $errors as $value ) {
						$text .= $value . '</br>';
					}
					if ( is_admin() ) {
						return array(
							'error' => $text,
						);
					}
				} elseif ( is_admin() ) {
					return array(
						'success' => esc_html__( 'Profile updated successfully.', 'wk-marketplace' ),
					);
				}
			}
		}
	}
}
