<?php
/**
 * Seller back end query list.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Separate_Dashboard;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplace\Helper\Common;

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

if ( ! class_exists( 'WKMP_Seller_Backend_Query_List' ) ) {

	/**
	 * WKMP_Seller_Backend query class
	 */
	class WKMP_Seller_Backend_Query_List extends \WP_List_Table {
		/**
		 * Instance variable.
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Class constructor.
		 */
		public function __construct() {
			parent::__construct(
				array(
					'singular' => 'Query',
					'plural'   => 'Queries',
					'ajax'     => false,
				)
			);
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Function prepare items.
		 */
		public function prepare_items() {
			$columns      = $this->get_columns();
			$sortable     = $this->get_sortable_columns();
			$hidden       = $this->get_hidden_columns();
			$per_page     = 20;
			$current_page = $this->get_pagenum();
			$data         = $this->table_data( $current_page, $per_page );
			$data         = empty( $data ) ? array() : $data;
			$total_items  = count( $data );

			$this->_column_headers = array( $columns, $hidden, $sortable );

			$total_pages = ceil( $total_items / $per_page );

			$this->set_pagination_args(
				array(
					'total_items' => $total_items,
					'total_pages' => $total_pages,
					'per_page'    => $per_page,
				)
			);

			$this->items = $data;
		}

		/**
		 * Get hidden columns
		 */
		public function get_hidden_columns() {
			return array();
		}

		/**
		 * Get columns.
		 */
		public function get_columns() {
			$columns = array(
				'date'    => esc_html__( 'Date', 'wk-marketplace' ),
				'subject' => esc_html__( 'Subject', 'wk-marketplace' ),
				'message' => esc_html__( 'Message', 'wk-marketplace' ),
			);

			return $columns;
		}

		/**
		 * Get sortable columns
		 */
		public function get_sortable_columns() {
			$sortable_columns = array(
				'date'    => array( 'date', true ),
				'subject' => array( 'subject', true ),
			);

			return $sortable_columns;
		}

		/**
		 * Returns columns data.
		 *
		 * @param array  $item data array.
		 * @param string $column_name col name.
		 */
		public function column_default( $item, $column_name ) {
			switch ( $column_name ) {
				case 'date':
				case 'subject':
				case 'message':
					return $item[ $column_name ];
				default:
					return '-';
			}
		}

		/**
		 * Function for retrieving data from table.
		 *
		 * @param int $current_page Current page.
		 * @param int $limit Limit.
		 *
		 * @return array()
		 */
		private function table_data( $current_page, $limit ) {
			$query_db_object = Common\WKMP_Seller_Ask_Queries::get_instance();

			$user_id    = get_current_user_id();
			$search     = \WK_Caching::wk_get_request_data( 's' );
			$orderby    = \WK_Caching::wk_get_request_data( 'orderby', array( 'default' => 'date' ) );
			$sort_order = \WK_Caching::wk_get_request_data( 'order', array( 'default' => 'desc' ) );

			$filter_data = array(
				'seller_id' => $user_id,
				'offset'    => ( $current_page - 1 ) * $limit,
				'limit'     => $limit,
				'search'    => $search,
				'orderby'   => $orderby,
				'order'     => $sort_order,
			);

			$query_result = $query_db_object->wkmp_get_all_seller_queries( $filter_data );

			$data = array();

			foreach ( is_array( $query_result ) ? $query_result : array() as $value ) {
				$data[] = array(
					'date'    => empty( $value['create_date'] ) ? '-' : get_date_from_gmt( $value['create_date'] ),
					'subject' => empty( $value['subject'] ) ? '-' : $value['subject'],
					'message' => empty( $value['message'] ) ? '-' : $value['message'],
				);
			}

			return $data;
		}
	}
}
