<?php
/**
 * Seller backend shop followers.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Separate_Dashboard;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplace\Templates\Front\Seller;
use WkMarketplace\Helper;

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

if ( ! class_exists( 'WKMP_Seller_Backend_Shop_Followers' ) ) {

	/**
	 * Class for listing seller queries.
	 */
	class WKMP_Seller_Backend_Shop_Followers extends \WP_List_Table {
		/**
		 * Instance variable.
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * WKMP_Seller_Backend_Shop_Followers constructor.
		 */
		public function __construct() {
			parent::__construct(
				array(
					'singular' => esc_html__( 'Query', 'wk-marketplace' ),
					'plural'   => esc_html__( 'Queries', 'wk-marketplace' ),
					'ajax'     => false,
				)
			);
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Prepare item.
		 */
		public function prepare_items() {
			$columns  = $this->get_columns();
			$sortable = $this->get_sortable_columns();
			$hidden   = $this->get_hidden_columns();
			$this->process_bulk_action();

			$data = $this->table_data();
			$data = empty( $data ) ? array() : $data;

			$total_items           = count( $data );
			$per_page              = 20;
			$this->_column_headers = array( $columns, $hidden, $sortable );

			$total_pages  = ceil( $total_items / $per_page );
			$current_page = $this->get_pagenum();
			$data         = array_slice( $data, ( ( $current_page - 1 ) * $per_page ), $per_page );

			$this->set_pagination_args(
				array(
					'total_items' => $total_items,
					'total_pages' => $total_pages,
					'per_page'    => $per_page,
				)
			);

			$this->items = $data;
		}

		/**
		 * For hidden columns.
		 */
		public function get_hidden_columns() {
			return array();
		}

		/**
		 * Get columns.
		 *
		 * @return array
		 */
		public function get_columns() {
			return array(
				'cb'             => '<input type="checkbox" />',
				'follower_name'  => esc_html__( 'Customer Name', 'wk-marketplace' ),
				'follower_email' => esc_html__( 'Customer Email', 'wk-marketplace' ),
			);
		}

		/**
		 * Get Default columns.
		 *
		 * @param array  $item item data.
		 * @param string $column_name col name.
		 */
		public function column_default( $item, $column_name ) {
			switch ( $column_name ) {
				case 'cb':
				case 'follower_name':
				case 'follower_email':
					return $item[ $column_name ];
				default:
					return '-';
			}
		}

		/**
		 * Column checkbox data.
		 *
		 * @param array $item item array.
		 */
		public function column_cb( $item ) {
			return sprintf( '<input type="checkbox" id="user_%s" name="user[]" value="%s" />', $item['follower_id'], $item['follower_id'] );
		}

		/**
		 * Column checkbox data.
		 *
		 * @param array $item item array.
		 */
		public function column_name( $item ) {
			$actions = array(
				'delete' => sprintf( '<a class="submitdelete" href="?page=seller-shop-followers&action=delete&user=%s&_wpnonce=%s">Delete</a>', $item['follower_id'], wp_create_nonce( 'del_mp_nonceuser_' . $item['follower_id'] ) ),
			);

			return sprintf( '%1$s %2$s', $item['follower_name'], $this->row_actions( $actions ) );
		}

		/**
		 * Bulk action.
		 */
		public function get_bulk_actions() {
			$actions = array(
				'delete' => esc_html__( 'Delete', 'wk-marketplace' ),
			);

			return $actions;
		}

		/**
		 * Process bulk action.
		 */
		public function process_bulk_action() {
			$deleted     = false;
			$action_name = \WK_Caching::wk_get_request_data( 'action' );
			$user_ids    = \WK_Caching::wk_get_request_data( 'user', array( 'flag' => 'array' ) );

			if ( ! empty( $user_ids ) && 'delete' === $action_name ) {
				$user_ids  = is_array( $user_ids ) ? $user_ids : array( $user_ids );
				$user_ids  = array_map( 'intval', $user_ids );
				$seller_id = get_current_user_id();

				if ( $seller_id > 0 ) {
					$db_obj = Helper\WKMP_General_Queries::get_instance();
					foreach ( $user_ids as $user_id ) {
						if ( method_exists( $db_obj, 'wkmp_update_shop_followers' ) ) {
							$deleted = $db_obj->wkmp_update_shop_followers( $seller_id, $user_id );
						}
					}
				}
			}
			if ( $deleted ) {
				?>
			<div class="updated notice is-dismissible">
				<p><?php esc_html_e( 'Shop followers has been deleted successfully', 'wk-marketplace' ); ?> </p>
			</div>
				<?php
			}
		}

		/**
		 * Get data for Table.
		 */
		private function table_data() {
			$helper = Seller\WKMP_Shop_Follower::get_instance();

			$seller_id = get_current_user_id();

			return $helper->wkmp_get_seller_followers_data( $seller_id );
		}
	}
}
