<?php
/**
 * Customer Become Seller Class.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Templates\Front\Customer;

use WkMarketplacePro\Helper;
use WkMarketplace\Helper\Common;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMP_Customer_Become_Seller' ) ) {
	/**
	 * Customer Become Seller Class.
	 *
	 * Class WKMP_Customer_Become_Seller
	 *
	 * @package WkMarketplace\Templates\Front\Customer
	 */
	class WKMP_Customer_Become_Seller {
		/**
		 * Current logged in customer id.
		 *
		 * @var object
		 */
		private $customer_id;

		/**
		 * General query helper variable
		 *
		 * @var object
		 */
		private $query_handler;

		/**
		 * Constructor of the class.
		 *
		 * WKMP_Customer_Become_Seller constructor.
		 *
		 * @param int $customer_id Customer id.
		 */
		public function __construct( $customer_id = 0 ) {
			$this->customer_id   = $customer_id;
			$this->query_handler = Helper\WKMP_General_Queries_Pro::get_instance();
			$posted_data         = array();

			$nonce_value = \WK_Caching::wk_get_request_data( 'wkmp-become-seller-nonce', array( 'method' => 'post' ) );

			if ( ! empty( $nonce_value ) && wp_verify_nonce( $nonce_value, 'wkmp-become-seller-nonce' ) ) {
				$posted_data['first_name']    = empty( $_POST['wkmp_firstname'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_firstname'] ) );
				$posted_data['last_name']     = empty( $_POST['wkmp_lastname'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_lastname'] ) );
				$posted_data['shopname']      = empty( $_POST['wkmp_shopname'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_shopname'] ) );
				$posted_data['shopurl']       = empty( $_POST['wkmp_shopurl'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_shopurl'] ) );
				$posted_data['shopphone']     = empty( $_POST['wkmp_shopphone'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_shopphone'] ) );
				$posted_data['customer_id']   = empty( $_POST['wkmp_customer_id'] ) ? 0 : intval( wp_unslash( $_POST['wkmp_customer_id'] ) );
				$posted_data['term_accepted'] = empty( $_POST['wkmp_seller_signup_term_accept'] ) ? '' : wc_clean( wp_unslash( $_POST['wkmp_seller_signup_term_accept'] ) );

				$this->wkmp_become_a_seller( $posted_data );
			}

			$this->wkmp_display_customer_become_seller_form( $posted_data );
		}

		/**
		 * Become a seller form post handler.
		 *
		 * @param array $data Customer data.
		 */
		public function wkmp_become_a_seller( $data ) {
			global $wkmarketplace;
			$customer_id = isset( $data['customer_id'] ) ? intval( $data['customer_id'] ) : get_current_user_id();

			if ( $customer_id > 0 && ! empty( $data ) ) {
				$errors        = array();
				$first_name    = $data['first_name'];
				$last_name     = $data['last_name'];
				$shop_name     = $data['shopname'];
				$store_url     = $data['shopurl'];
				$sel_phone     = $data['shopphone'];
				$term_accepted = 'yes' === trim( $data['term_accepted'] );

				$user                = $wkmarketplace->wkmp_get_seller_id_by_shop_address( $store_url );
				$seller_term_page_id = get_option( 'wkmp_seller_terms_page_id', 0 );

				if ( empty( $first_name ) ) {
					$errors[] = esc_html__( 'Please enter your first name.', 'wk-marketplace' );
				}

				if ( empty( $last_name ) ) {
					$errors[] = esc_html__( 'Please enter your last name.', 'wk-marketplace' );
				}

				$shopname_visibility = get_option( 'wkmp_shop_name_visibility', 'required' );

				if ( 'remove' !== $shopname_visibility ) {
					if ( ( empty( $shop_name ) && 'required' === $shopname_visibility ) || ( ! empty( $shop_name ) && ! preg_match( '/^[-A-Za-z0-9_\s]{1,40}$/', $shop_name ) ) ) {
						$errors[] = esc_html__( 'Enter a valid shop name.', 'wk-marketplace' );
					}
				}

				$shopurl_visibility = get_option( 'wkmp_shop_url_visibility', 'required' );

				if ( 'remove' !== $shopurl_visibility ) {
					if ( empty( $store_url ) && 'required' === $shopurl_visibility ) {
						$errors[] = esc_html__( 'Please enter valid shop URL.', 'wk-marketplace' );
					} elseif ( preg_match( '/[\'^£$%&*()}{@#~?><>,|=_+¬]/', $store_url ) ) {
						$errors[] = esc_html__( 'You can not use special characters in shop url except HYPHEN(-).', 'wk-marketplace' );
					} elseif ( ctype_space( $store_url ) ) {
						$errors[] = esc_html__( 'White space(s) aren\'t allowed in shop url.', 'wk-marketplace' );
					} elseif ( $user ) {
						$errors[] = esc_html__( 'This shop URl already EXISTS, please try different shop url.', 'wk-marketplace' );
					}
				}

				if ( empty( $sel_phone ) || strlen( $sel_phone ) > 18 || ! preg_match( '/^\s*(?:\+?(\d{1,3}))?([-. (]*(\d{3})[-. )]*)?((\d{3})[-. ]*(\d{2,4})(?:[-.x ]*(\d+))?)\s*$/', $sel_phone ) ) {
					$errors[] = esc_html__( 'Please enter a valid phone number.', 'wk-marketplace' );
				}

				if ( $seller_term_page_id > 0 && empty( $term_accepted ) ) {
					$errors[] = esc_html__( 'Please accept sign up terms and conditions.', 'wk-marketplace' );
				}

				if ( ! empty( $errors ) ) {
					foreach ( $errors as $error ) {
						wc_print_notice( $error, 'error' );
					}
				} else {
					$customer_user = get_user_by( 'ID', $customer_id );
					$auto_approve  = get_option( '_wkmp_auto_approve_seller', false );

					$user_email = ( $customer_user instanceof \WP_User ) ? $customer_user->user_email : 'NA';
					$user_login = ( $customer_user instanceof \WP_User ) ? $customer_user->user_login : 'NA';

					$data = array(
						'user_id'      => $customer_id,
						'user_email'   => $user_email,
						'user_login'   => $user_login,
						'auto_approve' => $auto_approve,
						'firstname'    => $first_name,
						'lastname'     => $last_name,
						'store_name'   => $shop_name,
						'shop_url'     => $store_url,
						'phone'        => $sel_phone,
					);

					update_user_meta( $customer_id, 'first_name', $first_name );
					update_user_meta( $customer_id, 'billing_first_name', $first_name );
					update_user_meta( $customer_id, 'last_name', $last_name );
					update_user_meta( $customer_id, 'billing_last_name', $last_name );
					update_user_meta( $customer_id, 'shop_name', $shop_name );
					update_user_meta( $customer_id, 'shop_address', $store_url );
					update_user_meta( $customer_id, 'billing_phone', $sel_phone );

					$commission_helper = Common\WKMP_Commission::get_instance();

					$this->query_handler->wkmp_set_seller_meta( $customer_id );
					$commission_helper->wkmp_set_seller_default_commission( $customer_id );

					$success_message = esc_html__( 'Your request has been successfully sent to Administrator. You will be notified via Email once it is processed.', 'wk-marketplace' );

					if ( $auto_approve ) {
						$success_message = esc_html__( 'Congratulations!! Your request has been accepted. Now you are a seller on the site.', 'wk-marketplace' );
					}

					update_user_meta( $customer_id, 'wkmp_show_register_notice', $success_message );

					do_action( 'wkmp_customer_become_seller', $data );
					do_action( 'wkmp_customer_become_seller_to_admin', $data );
				}
			}
		}

		/**
		 * Display Become seller form.
		 *
		 * @param array $posted_data Posted form data.
		 */
		public function wkmp_display_customer_become_seller_form( $posted_data = array() ) {
			global $wkmarketplace;
			$customer_id = get_current_user_id();

			if ( $wkmarketplace->wkmp_user_is_pending_seller( $customer_id ) || ! $wkmarketplace->wkmp_user_is_customer( $customer_id ) ) {
				$wkmp_notice = get_user_meta( $customer_id, 'wkmp_show_register_notice', true );
				if ( ! empty( $wkmp_notice ) ) {
					wc_print_notice( esc_html( $wkmp_notice ) );
					delete_user_meta( $customer_id, 'wkmp_show_register_notice' );
				} else {
					wc_print_notice( esc_html__( 'You are not allowed to access this page.', 'wk-marketplace' ), 'error' );
				}
				return false;
			}

			$first_name = empty( $posted_data['first_name'] ) ? '' : $posted_data['first_name'];
			$last_name  = empty( $posted_data['last_name'] ) ? '' : $posted_data['last_name'];
			$shop_name  = empty( $posted_data['shopname'] ) ? '' : $posted_data['shopname'];
			$store_url  = empty( $posted_data['shopurl'] ) ? '' : $posted_data['shopurl'];
			$phone      = empty( $posted_data['shopphone'] ) ? '' : $posted_data['shopphone'];

			if ( empty( $posted_data ) ) {
				$first_name = get_user_meta( $customer_id, 'first_name', true );
				$first_name = empty( $first_name ) ? get_user_meta( $customer_id, 'billing_first_name', true ) : $first_name;
				$first_name = empty( $first_name ) ? get_user_meta( $customer_id, 'shipping_first_name', true ) : $first_name;

				$last_name = get_user_meta( $customer_id, 'last_name', true );
				$last_name = empty( $last_name ) ? get_user_meta( $customer_id, 'billing_last_name', true ) : $last_name;
				$last_name = empty( $last_name ) ? get_user_meta( $customer_id, 'shipping_last_name', true ) : $last_name;

				$phone = get_user_meta( $customer_id, 'billing_phone', true );
			}
			?>
			<form action="" method="post" enctype="multipart/form-data" class="wkmp-form-wrap wkmp-customer-become-seller" id="wkmp-customer-become-seller">
				<div class="wkmp-seller-registration-fields">
					<div class="wkmp-show-fields-if-seller">
						<?php
						if ( isset( $posted_data['first_name'] ) || ( empty( $first_name ) || empty( $last_name ) ) ) {
							?>
							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="wkmp-firstname"><?php esc_html_e( 'First Name', 'wk-marketplace' ); ?> <span class="required">*</span></label>
								<input type="text" class="input-text form-control" name="wkmp_firstname" value="<?php echo esc_attr( $first_name ); ?>" id="wkmp-firstname"/>
							</p>

							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="wkmp-lastname"><?php esc_html_e( 'Last Name', 'wk-marketplace' ); ?> <span class="required">*</span></label>
								<input type="text" class="input-text form-control" name="wkmp_lastname" value="<?php echo esc_attr( $last_name ); ?>" id="wkmp-lastname"/>
							</p>
							<?php
						} else {
							?>
							<input type="hidden" name="wkmp_firstname" value="<?php echo esc_attr( $first_name ); ?>">
							<input type="hidden" name="wkmp_lastname" value="<?php echo esc_attr( $last_name ); ?>">
							<?php
						}

						$shopname_visibility = get_option( 'wkmp_shop_name_visibility', 'required' );
						if ( 'remove' !== $shopname_visibility ) {
							?>
							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="wkmp-shopname"><?php esc_html_e( 'Shop Name', 'wk-marketplace' ); ?><?php echo ( 'required' === $shopname_visibility ) ? '<span class="required">*</span>' : ''; ?></label>
								<input type="text" class="input-text form-control" name="wkmp_shopname" value="<?php echo esc_attr( $shop_name ); ?>" id="wkmp-shopname"/>
							</p>
							<?php
						}

						$shopurl_visibility = get_option( 'wkmp_shop_url_visibility', 'required' );

						if ( 'remove' !== $shopurl_visibility ) {
							?>
							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label for="wkmp-shopurl" class="pull-left"><?php esc_html_e( 'Shop URL', 'wk-marketplace' ); ?> <?php echo ( 'required' === $shopurl_visibility ) ? '<span class="required">*</span>' : ''; ?></label>
								<input type="text" class="input-text form-control" name="wkmp_shopurl" value="<?php echo esc_attr( $store_url ); ?>" id="wkmp-shopurl"/>
								<strong id="wkmp-shop-url-availability"></strong>
							</p>
							<?php
						}
						?>
						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label for="wkmp-shopphone"><?php esc_html_e( 'Phone Number', 'wk-marketplace' ); ?><span class="required">*</span></label>
							<input type="text" class="input-text form-control" name="wkmp_shopphone" value="<?php echo empty( $phone ) ? '' : esc_attr( $phone ); ?>" id="wkmp-shopphone"/>
						</p>
						<?php do_action( 'wk_mkt_add_register_field' ); ?>
					</div>
					<?php wp_nonce_field( 'wkmp-become-seller-nonce-action', 'wkmp-become-seller-nonce' ); ?>
					<input type="hidden" name="wkmp_customer_id" value="<?php echo esc_attr( $customer_id ); ?>">
					<input type="submit" name="wkmp-submit-become-seller" class="button button-primary" value="<?php esc_attr_e( 'Made Request', 'wk-marketplace' ); ?>"/>
				</div>
			</form>
			<?php
		}
	}
}
