<?php
/**
 * Seller template functions.
 *
 * @package Marketplace for WooCommerce
 */

namespace WkMarketplacePro\Templates\Front\Seller;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

use WkMarketplacePro\Helper\Front;

if ( ! class_exists( 'WKMP_Seller_Template_Functions_Pro' ) ) {

	/**
	 * Seller template functions class.
	 */
	class WKMP_Seller_Template_Functions_Pro {
		/**
		 * Seller id.
		 *
		 * @var int $seller_id Seller id.
		 */
		private $seller_id = '';

		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * Constructor of the class
		 */
		public function __construct() {
			$this->seller_id = get_current_user_id();
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Callback method for seller Shippings.
		 *
		 * @return void
		 */
		public function wkmp_pro_shippings_content() {
			if ( 'disabled' !== get_option( 'woocommerce_ship_to_countries', false ) ) {
				global $wp, $wpdb;

				$logged_in_user_id = get_current_user_id();
				$hidden_user       = 0;

				$seller_id    = $this->seller_id;
				$shipping     = Shipping\WKMP_Shipping::get_instance();
				$shippings    = get_option( '_wkmp_shipping_endpoint', 'seller-shippings' );
				$action_value = empty( $wp->query_vars[ $shippings ] ) ? '' : $wp->query_vars[ $shippings ];

				$nonce_value = \WK_Caching::wk_get_request_data( 'shipping_nonce', array( 'method' => 'post' ) );

				if ( ! empty( $nonce_value ) && wp_verify_nonce( $nonce_value, 'shipping_action' ) ) {

					$hidden_user = empty( $_POST['hidden_user'] ) ? 0 : intval( $_POST['hidden_user'] );
					$posted_data = array();

					if ( $hidden_user > 0 && $hidden_user === $logged_in_user_id ) {
						$shipping_details = empty( $_POST['save_shipping_details'] ) ? array() : wc_clean( $_POST['save_shipping_details'] );

						if ( empty( $shipping_details ) ) {
							$zone_id        = empty( $_POST['mp_zone_id'] ) ? 0 : intval( $_POST['mp_zone_id'] );
							$zone_seller_id = 0;

							if ( ! empty( $zone_id ) ) {
								$zone_seller_id = $wpdb->get_var( $wpdb->prepare( "SELECT `seller_id` FROM {$wpdb->prefix}mpseller_meta WHERE zone_id = %d", $zone_id ) );
							}

							if ( ! empty( $zone_seller_id ) && intval( $zone_seller_id ) === $logged_in_user_id ) {
								$shipping_details               = empty( $_POST['update_shipping_details'] ) ? array() : wc_clean( $_POST['update_shipping_details'] );
								$posted_data['update_shipping'] = true;
								$posted_data['mp_zone_id']      = $zone_id;
							}
						}

						if ( ! empty( $shipping_details ) ) {
							$posted_data['mp_zone_name']     = empty( $_POST['mp_zone_name'] ) ? array() : wc_clean( $_POST['mp_zone_name'] );
							$posted_data['zone_postcodes']   = empty( $_POST['zone_postcodes'] ) ? array() : wc_clean( $_POST['zone_postcodes'] );
							$posted_data['zone_locations']   = empty( $_POST['zone_locations'] ) ? array() : wc_clean( $_POST['zone_locations'] );
							$posted_data['shipping_details'] = $shipping_details;

							$db_shipping_obj = Front\WKMP_Shipping_Queries_Pro::get_instance();
							$db_shipping_obj->wkmp_save_shipping_details( $posted_data );
						}
					} elseif ( $hidden_user > 0 && $hidden_user !== $logged_in_user_id ) {
						wc_print_notice( esc_html__( 'You are not allowed to update this shipping zone.', 'wk-marketplace' ), 'error' );
					}
				} elseif ( ! empty( $nonce_value ) ) {
					wc_add_notice( esc_html__( 'Sorry, your nonce did not verify.', 'wk-marketplace' ), 'error' );
				}

				if ( 'add' === $action_value && empty( $hidden_user ) ) {
					$shipping->wkmp_add_shipping( $seller_id );
				} elseif ( intval( $action_value ) > 0 ) {
					$shipping->wkmp_edit_shipping( $action_value, $seller_id );
				} else {
					$shipping->wkmp_shipping_list( $seller_id );
				}
			} else {
				echo '<div class="woocommerce-message woocommerce-error">';
				esc_html_e( 'Shipping is not enabled by the Admin.', 'wk-marketplace' );
				echo '</div>';
			}
		}
	}
}
