<?php
/**
 * Seller product at front.
 *
 * @package Marketplace for WooCommerce
 * @version 5.0.0
 */

namespace WkMarketplacePro\Templates\Front\Seller\Shipping;

use WkMarketplacePro\Helper\Front;

defined( 'ABSPATH' ) || exit; // Exit if access directly.

if ( ! class_exists( 'WKMP_Shipping' ) ) {
	/**
	 * Seller products class
	 */
	class WKMP_Shipping {

		/**
		 * Seller id.
		 *
		 * @var int $seller_id Seller id.
		 */
		private $seller_id;

		/**
		 * Instance variable
		 *
		 * @var $instance
		 */
		protected static $instance = null;

		/**
		 * DB Shipping Object.
		 *
		 * @var Front\WKMP_Shipping_Queries $db_shipping_obj DB Shipping Object.
		 */
		private $db_shipping_obj;

		/**
		 * Constructor of the class.
		 *
		 * WKMP_Shipping constructor.
		 *
		 * @param int $seller_id Seller id.
		 */
		public function __construct( $seller_id = 0 ) {
			$this->seller_id       = $seller_id;
			$this->db_shipping_obj = Front\WKMP_Shipping_Queries_Pro::get_instance();
		}

		/**
		 * Ensures only one instance of this class is loaded or can be loaded.
		 *
		 * @return object
		 */
		public static function get_instance() {
			if ( ! static::$instance ) {
				static::$instance = new self();
			}
			return static::$instance;
		}

		/**
		 * Add seller shipping.
		 *
		 * @param int $seller_id Seller id.
		 *
		 * @return void
		 */
		public function wkmp_add_shipping( $seller_id ) {
			$seller_id = empty( $seller_id ) ? 0 : $seller_id;
			require_once __DIR__ . '/wkmp-add-shipping.php';
		}

		/**
		 * Edit seller shipping.
		 *
		 * @param int $zone_id Zone id.
		 * @param int $seller_id Seller id.
		 *
		 * @return void
		 */
		public function wkmp_edit_shipping( $zone_id, $seller_id ) {
			global $wpdb;

			$message = '';

			try {
				$seller_zone_check = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}mpseller_meta WHERE seller_id = %d AND zone_id = %d", $seller_id, $zone_id ) );

				if ( ! empty( $seller_zone_check ) ) {
					$zones          = new \WC_Shipping_Zone( $zone_id );
					$zone_name      = $zones->get_zone_name();
					$zone_locations = $zones->get_zone_locations();

					require_once __DIR__ . '/wkmp-edit-shipping.php';
				} else {
					$message = esc_html__( 'Invalid shipping zone id.', 'wk-marketplace' );
				}
			} catch ( \Exception $e ) {
				$message = $e->getMessage();
			}

			if ( ! empty( $message ) ) {
				wc_print_notice( $message, 'error' );
			}
		}

		/**
		 * Seller shipping list.
		 *
		 * @param int $seller_id Seller id.
		 *
		 * @return void
		 */
		public function wkmp_shipping_list( $seller_id ) {
			global $wkmarketplace;
			$seller_info = $wkmarketplace->wkmp_get_seller_info( $seller_id );

			require_once __DIR__ . '/wkmp-shipping-list.php';
		}
	}
}
