<?php //phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Plugin Name: Marketplace for WooCommerce
 * Plugin URI: https://codecanyon.net/item/wordpress-woocommerce-marketplace-plugin/19214408
 * Description: Adds several advance features to Marketplace Lite for WooCommerce plugin. Also enables <a href="admin.php?page=wk-marketplace-extensions&ext_tab=3">50+ Marketplace addons</a> to work.
 * Version: 5.5.1
 * Author: Webkul
 * Author URI: https://webkul.com
 * Text Domain: wk-marketplace
 * Domain Path: /languages
 *
 * Requires at least: 5.0
 * Requires PHP: 7.4
 * WC requires at least: 5.0
 * WC tested up to: 8.5
 * MP Lite Required at least: 1.0.0
 * MP Lite test up to: 1.0.1
 *
 * Store URI: https://store.webkul.com/woocommerce-multivendor-marketplace.html
 * Blog URI: https://webkul.com/blog/wordpress-woocommerce-marketplace/
 *
 * Requires Plugins: woocommerce
 *
 * WPML Compatible: yes
 * Multisite Compatible: yes
 *
 * @package Marketplace for WooCommerce
 */

defined( 'ABSPATH' ) || exit(); // Exit if access directly.

use WkMarketplacePro\Includes;

// Define Constants.
defined( 'WKMP_FILE' ) || define( 'WKMP_FILE', __FILE__ );
defined( 'WKMP_PLUGIN_FILE' ) || define( 'WKMP_PLUGIN_FILE', plugin_dir_path( __FILE__ ) );
defined( 'WKMP_PLUGIN_URL' ) || define( 'WKMP_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
defined( 'WKMP_SCRIPT_VERSION' ) || define( 'WKMP_SCRIPT_VERSION', '5.5.1' );
defined( 'MARKETPLACE_VERSION' ) || define( 'MARKETPLACE_VERSION', '5.5.1' );
defined( 'WKMP_PLUGIN_BASENAME' ) || define( 'WKMP_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
defined( 'WKMP_LITE_PLUGIN_BASENAME' ) || define( 'WKMP_LITE_PLUGIN_BASENAME', 'multi-vendor-marketplace-lite-for-woocommerce/multi-vendor-marketplace-lite-for-woocommerce.php' );
defined( 'WKMP_LITE_MIN_VERSION' ) || define( 'WKMP_LITE_MIN_VERSION', '1.0.0' ); // To show notice if minimum required version is not installed.

// Class Marketplace for addon support.
if ( ! class_exists( 'Marketplace' ) ) {
	/**
	 * Marketplace class.
	 */
	final class Marketplace {
		/**
		 * Marketplace Constructor.
		 */
		public function __construct() {
			require_once WKMP_PLUGIN_FILE . 'inc/class-wkmp-autoload-pro.php';
			add_action( 'plugins_loaded', array( $this, 'wkmp_load_plugin_text_domain' ), 9 );
			register_deactivation_hook( WKMP_FILE, array( $this, 'wkmp_delete_pro_options' ) );
		}

		/**
		 * Loading text domain.
		 *
		 * @return void
		 */
		public function wkmp_load_plugin_text_domain() {
			load_plugin_textdomain( 'wk-marketplace', false, plugin_basename( __DIR__ ) . '/languages' );

			Includes\WKMarketplace_Pro::instance();
		}

		/**
		 * Loading test domain.
		 *
		 * @return void
		 */
		public function wkmp_delete_pro_options() {
			$option_keys = array(
				'_wkmp_auto_approve_seller',
				'_wkmp_separate_seller_dashboard',
				'_wkmp_separate_seller_registration',
				'wkmp_shipping_option',
				'wkmp_seller_terms_page_id',
				'_wkmp_allow_seller_to_publish',
			);

			foreach ( $option_keys as $option_key ) {
				delete_option( $option_key );
			}
		}
	}

	new Marketplace();
}

if ( ! function_exists( 'wkmp_allow_sellers_to_translate' ) ) {
	/**
	 * Allow seller to translate the products.
	 *
	 * @param array $capability Vendor capability.
	 *
	 * @return array
	 */
	function wkmp_allow_sellers_to_translate( $capability ) {
		global $wkmarketplace;
		$capability        = is_array( $capability ) ? $capability : array();
		$translate_allowed = get_option( '_wkmp_wcml_allow_product_translate', false );
		$user_id           = 0;

		if ( ! $translate_allowed ) {
			$user_id           = get_current_user_id();
			$translate_allowed = get_user_meta( $user_id, '_wkmp_wcml_allow_product_translate', true );
		}

		if ( $translate_allowed ) {
			$capability['vendor_capability'] = 'wk_marketplace_seller';
		} else {
			$wkmarketplace->wkmp_remove_seller_translate_capability( $user_id );
		}

		return $capability;
	}
	add_filter( 'wcml_vendor_addon_configuration', 'wkmp_allow_sellers_to_translate' );
}
